#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi


class OutputInvoiceReceiptOpenApiResponse(object):

    def __init__(self):
        self._arrangement_no = None
        self._can_appoint_invoice_mode = None
        self._inst_id = None
        self._inv_dt = None
        self._inv_mode = None
        self._invoice_amt = None
        self._invoiced_amt = None
        self._ip_id = None
        self._ip_role_id = None
        self._link_invoice_amt = None
        self._out_biz_no = None
        self._out_biz_type = None
        self._prod_code = None
        self._receivable_amount = None
        self._settle_type = None
        self._status = None
        self._tax_rate = None
        self._tax_type = None
        self._tnt_inst_id = None
        self._write_off_amount = None

    @property
    def arrangement_no(self):
        return self._arrangement_no

    @arrangement_no.setter
    def arrangement_no(self, value):
        self._arrangement_no = value
    @property
    def can_appoint_invoice_mode(self):
        return self._can_appoint_invoice_mode

    @can_appoint_invoice_mode.setter
    def can_appoint_invoice_mode(self, value):
        self._can_appoint_invoice_mode = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def inv_dt(self):
        return self._inv_dt

    @inv_dt.setter
    def inv_dt(self, value):
        self._inv_dt = value
    @property
    def inv_mode(self):
        return self._inv_mode

    @inv_mode.setter
    def inv_mode(self, value):
        self._inv_mode = value
    @property
    def invoice_amt(self):
        return self._invoice_amt

    @invoice_amt.setter
    def invoice_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._invoice_amt = value
        else:
            self._invoice_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def invoiced_amt(self):
        return self._invoiced_amt

    @invoiced_amt.setter
    def invoiced_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._invoiced_amt = value
        else:
            self._invoiced_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def link_invoice_amt(self):
        return self._link_invoice_amt

    @link_invoice_amt.setter
    def link_invoice_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._link_invoice_amt = value
        else:
            self._link_invoice_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def out_biz_type(self):
        return self._out_biz_type

    @out_biz_type.setter
    def out_biz_type(self, value):
        self._out_biz_type = value
    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value
    @property
    def receivable_amount(self):
        return self._receivable_amount

    @receivable_amount.setter
    def receivable_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._receivable_amount = value
        else:
            self._receivable_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def settle_type(self):
        return self._settle_type

    @settle_type.setter
    def settle_type(self, value):
        self._settle_type = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def tax_rate(self):
        return self._tax_rate

    @tax_rate.setter
    def tax_rate(self, value):
        self._tax_rate = value
    @property
    def tax_type(self):
        return self._tax_type

    @tax_type.setter
    def tax_type(self, value):
        self._tax_type = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value
    @property
    def write_off_amount(self):
        return self._write_off_amount

    @write_off_amount.setter
    def write_off_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._write_off_amount = value
        else:
            self._write_off_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.arrangement_no:
            if hasattr(self.arrangement_no, 'to_alipay_dict'):
                params['arrangement_no'] = self.arrangement_no.to_alipay_dict()
            else:
                params['arrangement_no'] = self.arrangement_no
        if self.can_appoint_invoice_mode:
            if hasattr(self.can_appoint_invoice_mode, 'to_alipay_dict'):
                params['can_appoint_invoice_mode'] = self.can_appoint_invoice_mode.to_alipay_dict()
            else:
                params['can_appoint_invoice_mode'] = self.can_appoint_invoice_mode
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.inv_dt:
            if hasattr(self.inv_dt, 'to_alipay_dict'):
                params['inv_dt'] = self.inv_dt.to_alipay_dict()
            else:
                params['inv_dt'] = self.inv_dt
        if self.inv_mode:
            if hasattr(self.inv_mode, 'to_alipay_dict'):
                params['inv_mode'] = self.inv_mode.to_alipay_dict()
            else:
                params['inv_mode'] = self.inv_mode
        if self.invoice_amt:
            if hasattr(self.invoice_amt, 'to_alipay_dict'):
                params['invoice_amt'] = self.invoice_amt.to_alipay_dict()
            else:
                params['invoice_amt'] = self.invoice_amt
        if self.invoiced_amt:
            if hasattr(self.invoiced_amt, 'to_alipay_dict'):
                params['invoiced_amt'] = self.invoiced_amt.to_alipay_dict()
            else:
                params['invoiced_amt'] = self.invoiced_amt
        if self.ip_id:
            if hasattr(self.ip_id, 'to_alipay_dict'):
                params['ip_id'] = self.ip_id.to_alipay_dict()
            else:
                params['ip_id'] = self.ip_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.link_invoice_amt:
            if hasattr(self.link_invoice_amt, 'to_alipay_dict'):
                params['link_invoice_amt'] = self.link_invoice_amt.to_alipay_dict()
            else:
                params['link_invoice_amt'] = self.link_invoice_amt
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.out_biz_type:
            if hasattr(self.out_biz_type, 'to_alipay_dict'):
                params['out_biz_type'] = self.out_biz_type.to_alipay_dict()
            else:
                params['out_biz_type'] = self.out_biz_type
        if self.prod_code:
            if hasattr(self.prod_code, 'to_alipay_dict'):
                params['prod_code'] = self.prod_code.to_alipay_dict()
            else:
                params['prod_code'] = self.prod_code
        if self.receivable_amount:
            if hasattr(self.receivable_amount, 'to_alipay_dict'):
                params['receivable_amount'] = self.receivable_amount.to_alipay_dict()
            else:
                params['receivable_amount'] = self.receivable_amount
        if self.settle_type:
            if hasattr(self.settle_type, 'to_alipay_dict'):
                params['settle_type'] = self.settle_type.to_alipay_dict()
            else:
                params['settle_type'] = self.settle_type
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.tax_rate:
            if hasattr(self.tax_rate, 'to_alipay_dict'):
                params['tax_rate'] = self.tax_rate.to_alipay_dict()
            else:
                params['tax_rate'] = self.tax_rate
        if self.tax_type:
            if hasattr(self.tax_type, 'to_alipay_dict'):
                params['tax_type'] = self.tax_type.to_alipay_dict()
            else:
                params['tax_type'] = self.tax_type
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        if self.write_off_amount:
            if hasattr(self.write_off_amount, 'to_alipay_dict'):
                params['write_off_amount'] = self.write_off_amount.to_alipay_dict()
            else:
                params['write_off_amount'] = self.write_off_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OutputInvoiceReceiptOpenApiResponse()
        if 'arrangement_no' in d:
            o.arrangement_no = d['arrangement_no']
        if 'can_appoint_invoice_mode' in d:
            o.can_appoint_invoice_mode = d['can_appoint_invoice_mode']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'inv_dt' in d:
            o.inv_dt = d['inv_dt']
        if 'inv_mode' in d:
            o.inv_mode = d['inv_mode']
        if 'invoice_amt' in d:
            o.invoice_amt = d['invoice_amt']
        if 'invoiced_amt' in d:
            o.invoiced_amt = d['invoiced_amt']
        if 'ip_id' in d:
            o.ip_id = d['ip_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'link_invoice_amt' in d:
            o.link_invoice_amt = d['link_invoice_amt']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'out_biz_type' in d:
            o.out_biz_type = d['out_biz_type']
        if 'prod_code' in d:
            o.prod_code = d['prod_code']
        if 'receivable_amount' in d:
            o.receivable_amount = d['receivable_amount']
        if 'settle_type' in d:
            o.settle_type = d['settle_type']
        if 'status' in d:
            o.status = d['status']
        if 'tax_rate' in d:
            o.tax_rate = d['tax_rate']
        if 'tax_type' in d:
            o.tax_type = d['tax_type']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        if 'write_off_amount' in d:
            o.write_off_amount = d['write_off_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AccessPurchaseOrder import AccessPurchaseOrder


class KoubeiSalesKbassetStuffPurchaseorderQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiSalesKbassetStuffPurchaseorderQueryResponse, self).__init__()
        self._asset_purchase_orders = None
        self._has_next_page = None

    @property
    def asset_purchase_orders(self):
        return self._asset_purchase_orders

    @asset_purchase_orders.setter
    def asset_purchase_orders(self, value):
        if isinstance(value, list):
            self._asset_purchase_orders = list()
            for i in value:
                if isinstance(i, AccessPurchaseOrder):
                    self._asset_purchase_orders.append(i)
                else:
                    self._asset_purchase_orders.append(AccessPurchaseOrder.from_alipay_dict(i))
    @property
    def has_next_page(self):
        return self._has_next_page

    @has_next_page.setter
    def has_next_page(self, value):
        self._has_next_page = value

    def parse_response_content(self, response_content):
        response = super(KoubeiSalesKbassetStuffPurchaseorderQueryResponse, self).parse_response_content(response_content)
        if 'asset_purchase_orders' in response:
            self.asset_purchase_orders = response['asset_purchase_orders']
        if 'has_next_page' in response:
            self.has_next_page = response['has_next_page']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MallGoodsDetail import MallGoodsDetail


class KoubeiMallScanpurchasePreorderCreateModel(object):

    def __init__(self):
        self._biz_scene = None
        self._body = None
        self._channel = None
        self._goods_detail = None
        self._operator_id = None
        self._out_order_no = None
        self._shop_id = None
        self._store_id = None
        self._store_name = None
        self._subject = None
        self._terminal_id = None
        self._total_amount = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def body(self):
        return self._body

    @body.setter
    def body(self, value):
        self._body = value
    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def goods_detail(self):
        return self._goods_detail

    @goods_detail.setter
    def goods_detail(self, value):
        if isinstance(value, list):
            self._goods_detail = list()
            for i in value:
                if isinstance(i, MallGoodsDetail):
                    self._goods_detail.append(i)
                else:
                    self._goods_detail.append(MallGoodsDetail.from_alipay_dict(i))
    @property
    def operator_id(self):
        return self._operator_id

    @operator_id.setter
    def operator_id(self, value):
        self._operator_id = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def store_id(self):
        return self._store_id

    @store_id.setter
    def store_id(self, value):
        self._store_id = value
    @property
    def store_name(self):
        return self._store_name

    @store_name.setter
    def store_name(self, value):
        self._store_name = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value
    @property
    def terminal_id(self):
        return self._terminal_id

    @terminal_id.setter
    def terminal_id(self, value):
        self._terminal_id = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.body:
            if hasattr(self.body, 'to_alipay_dict'):
                params['body'] = self.body.to_alipay_dict()
            else:
                params['body'] = self.body
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.goods_detail:
            if isinstance(self.goods_detail, list):
                for i in range(0, len(self.goods_detail)):
                    element = self.goods_detail[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.goods_detail[i] = element.to_alipay_dict()
            if hasattr(self.goods_detail, 'to_alipay_dict'):
                params['goods_detail'] = self.goods_detail.to_alipay_dict()
            else:
                params['goods_detail'] = self.goods_detail
        if self.operator_id:
            if hasattr(self.operator_id, 'to_alipay_dict'):
                params['operator_id'] = self.operator_id.to_alipay_dict()
            else:
                params['operator_id'] = self.operator_id
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.store_id:
            if hasattr(self.store_id, 'to_alipay_dict'):
                params['store_id'] = self.store_id.to_alipay_dict()
            else:
                params['store_id'] = self.store_id
        if self.store_name:
            if hasattr(self.store_name, 'to_alipay_dict'):
                params['store_name'] = self.store_name.to_alipay_dict()
            else:
                params['store_name'] = self.store_name
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        if self.terminal_id:
            if hasattr(self.terminal_id, 'to_alipay_dict'):
                params['terminal_id'] = self.terminal_id.to_alipay_dict()
            else:
                params['terminal_id'] = self.terminal_id
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMallScanpurchasePreorderCreateModel()
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'body' in d:
            o.body = d['body']
        if 'channel' in d:
            o.channel = d['channel']
        if 'goods_detail' in d:
            o.goods_detail = d['goods_detail']
        if 'operator_id' in d:
            o.operator_id = d['operator_id']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'store_id' in d:
            o.store_id = d['store_id']
        if 'store_name' in d:
            o.store_name = d['store_name']
        if 'subject' in d:
            o.subject = d['subject']
        if 'terminal_id' in d:
            o.terminal_id = d['terminal_id']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ItemDiagnoseType import ItemDiagnoseType


class KoubeiMarketingDataDishdiagnosetypeBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingDataDishdiagnosetypeBatchqueryResponse, self).__init__()
        self._item_diagnose_type_list = None

    @property
    def item_diagnose_type_list(self):
        return self._item_diagnose_type_list

    @item_diagnose_type_list.setter
    def item_diagnose_type_list(self, value):
        if isinstance(value, list):
            self._item_diagnose_type_list = list()
            for i in value:
                if isinstance(i, ItemDiagnoseType):
                    self._item_diagnose_type_list.append(i)
                else:
                    self._item_diagnose_type_list.append(ItemDiagnoseType.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingDataDishdiagnosetypeBatchqueryResponse, self).parse_response_content(response_content)
        if 'item_diagnose_type_list' in response:
            self.item_diagnose_type_list = response['item_diagnose_type_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AoiInfoDTO import AoiInfoDTO
from alipay.aop.api.domain.ItemStoreDTO import ItemStoreDTO


class CircleRecommendItemDTO(object):

    def __init__(self):
        self._aoi_info = None
        self._discount = None
        self._item_cover = None
        self._item_detail_url = None
        self._item_id = None
        self._item_label = None
        self._item_name = None
        self._item_store = None
        self._original_price = None
        self._sales_info = None
        self._saved_money = None
        self._saved_money_info = None
        self._sell_price = None
        self._sold_quantity = None
        self._store_id = None

    @property
    def aoi_info(self):
        return self._aoi_info

    @aoi_info.setter
    def aoi_info(self, value):
        if isinstance(value, AoiInfoDTO):
            self._aoi_info = value
        else:
            self._aoi_info = AoiInfoDTO.from_alipay_dict(value)
    @property
    def discount(self):
        return self._discount

    @discount.setter
    def discount(self, value):
        self._discount = value
    @property
    def item_cover(self):
        return self._item_cover

    @item_cover.setter
    def item_cover(self, value):
        self._item_cover = value
    @property
    def item_detail_url(self):
        return self._item_detail_url

    @item_detail_url.setter
    def item_detail_url(self, value):
        self._item_detail_url = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def item_label(self):
        return self._item_label

    @item_label.setter
    def item_label(self, value):
        self._item_label = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def item_store(self):
        return self._item_store

    @item_store.setter
    def item_store(self, value):
        if isinstance(value, ItemStoreDTO):
            self._item_store = value
        else:
            self._item_store = ItemStoreDTO.from_alipay_dict(value)
    @property
    def original_price(self):
        return self._original_price

    @original_price.setter
    def original_price(self, value):
        self._original_price = value
    @property
    def sales_info(self):
        return self._sales_info

    @sales_info.setter
    def sales_info(self, value):
        self._sales_info = value
    @property
    def saved_money(self):
        return self._saved_money

    @saved_money.setter
    def saved_money(self, value):
        self._saved_money = value
    @property
    def saved_money_info(self):
        return self._saved_money_info

    @saved_money_info.setter
    def saved_money_info(self, value):
        self._saved_money_info = value
    @property
    def sell_price(self):
        return self._sell_price

    @sell_price.setter
    def sell_price(self, value):
        self._sell_price = value
    @property
    def sold_quantity(self):
        return self._sold_quantity

    @sold_quantity.setter
    def sold_quantity(self, value):
        self._sold_quantity = value
    @property
    def store_id(self):
        return self._store_id

    @store_id.setter
    def store_id(self, value):
        self._store_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.aoi_info:
            if hasattr(self.aoi_info, 'to_alipay_dict'):
                params['aoi_info'] = self.aoi_info.to_alipay_dict()
            else:
                params['aoi_info'] = self.aoi_info
        if self.discount:
            if hasattr(self.discount, 'to_alipay_dict'):
                params['discount'] = self.discount.to_alipay_dict()
            else:
                params['discount'] = self.discount
        if self.item_cover:
            if hasattr(self.item_cover, 'to_alipay_dict'):
                params['item_cover'] = self.item_cover.to_alipay_dict()
            else:
                params['item_cover'] = self.item_cover
        if self.item_detail_url:
            if hasattr(self.item_detail_url, 'to_alipay_dict'):
                params['item_detail_url'] = self.item_detail_url.to_alipay_dict()
            else:
                params['item_detail_url'] = self.item_detail_url
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.item_label:
            if hasattr(self.item_label, 'to_alipay_dict'):
                params['item_label'] = self.item_label.to_alipay_dict()
            else:
                params['item_label'] = self.item_label
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.item_store:
            if hasattr(self.item_store, 'to_alipay_dict'):
                params['item_store'] = self.item_store.to_alipay_dict()
            else:
                params['item_store'] = self.item_store
        if self.original_price:
            if hasattr(self.original_price, 'to_alipay_dict'):
                params['original_price'] = self.original_price.to_alipay_dict()
            else:
                params['original_price'] = self.original_price
        if self.sales_info:
            if hasattr(self.sales_info, 'to_alipay_dict'):
                params['sales_info'] = self.sales_info.to_alipay_dict()
            else:
                params['sales_info'] = self.sales_info
        if self.saved_money:
            if hasattr(self.saved_money, 'to_alipay_dict'):
                params['saved_money'] = self.saved_money.to_alipay_dict()
            else:
                params['saved_money'] = self.saved_money
        if self.saved_money_info:
            if hasattr(self.saved_money_info, 'to_alipay_dict'):
                params['saved_money_info'] = self.saved_money_info.to_alipay_dict()
            else:
                params['saved_money_info'] = self.saved_money_info
        if self.sell_price:
            if hasattr(self.sell_price, 'to_alipay_dict'):
                params['sell_price'] = self.sell_price.to_alipay_dict()
            else:
                params['sell_price'] = self.sell_price
        if self.sold_quantity:
            if hasattr(self.sold_quantity, 'to_alipay_dict'):
                params['sold_quantity'] = self.sold_quantity.to_alipay_dict()
            else:
                params['sold_quantity'] = self.sold_quantity
        if self.store_id:
            if hasattr(self.store_id, 'to_alipay_dict'):
                params['store_id'] = self.store_id.to_alipay_dict()
            else:
                params['store_id'] = self.store_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CircleRecommendItemDTO()
        if 'aoi_info' in d:
            o.aoi_info = d['aoi_info']
        if 'discount' in d:
            o.discount = d['discount']
        if 'item_cover' in d:
            o.item_cover = d['item_cover']
        if 'item_detail_url' in d:
            o.item_detail_url = d['item_detail_url']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'item_label' in d:
            o.item_label = d['item_label']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'item_store' in d:
            o.item_store = d['item_store']
        if 'original_price' in d:
            o.original_price = d['original_price']
        if 'sales_info' in d:
            o.sales_info = d['sales_info']
        if 'saved_money' in d:
            o.saved_money = d['saved_money']
        if 'saved_money_info' in d:
            o.saved_money_info = d['saved_money_info']
        if 'sell_price' in d:
            o.sell_price = d['sell_price']
        if 'sold_quantity' in d:
            o.sold_quantity = d['sold_quantity']
        if 'store_id' in d:
            o.store_id = d['store_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceAlideviceinfoOfflinecodeCreateModel(object):

    def __init__(self):
        self._biz_tag = None
        self._biz_tid = None
        self._biz_type = None
        self._item_id = None
        self._merchant_pid = None
        self._product_code = None
        self._protocol_version = None
        self._sn = None
        self._supplier_id = None

    @property
    def biz_tag(self):
        return self._biz_tag

    @biz_tag.setter
    def biz_tag(self, value):
        self._biz_tag = value
    @property
    def biz_tid(self):
        return self._biz_tid

    @biz_tid.setter
    def biz_tid(self, value):
        self._biz_tid = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def merchant_pid(self):
        return self._merchant_pid

    @merchant_pid.setter
    def merchant_pid(self, value):
        self._merchant_pid = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def protocol_version(self):
        return self._protocol_version

    @protocol_version.setter
    def protocol_version(self, value):
        self._protocol_version = value
    @property
    def sn(self):
        return self._sn

    @sn.setter
    def sn(self, value):
        self._sn = value
    @property
    def supplier_id(self):
        return self._supplier_id

    @supplier_id.setter
    def supplier_id(self, value):
        self._supplier_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_tag:
            if hasattr(self.biz_tag, 'to_alipay_dict'):
                params['biz_tag'] = self.biz_tag.to_alipay_dict()
            else:
                params['biz_tag'] = self.biz_tag
        if self.biz_tid:
            if hasattr(self.biz_tid, 'to_alipay_dict'):
                params['biz_tid'] = self.biz_tid.to_alipay_dict()
            else:
                params['biz_tid'] = self.biz_tid
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.merchant_pid:
            if hasattr(self.merchant_pid, 'to_alipay_dict'):
                params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
            else:
                params['merchant_pid'] = self.merchant_pid
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.protocol_version:
            if hasattr(self.protocol_version, 'to_alipay_dict'):
                params['protocol_version'] = self.protocol_version.to_alipay_dict()
            else:
                params['protocol_version'] = self.protocol_version
        if self.sn:
            if hasattr(self.sn, 'to_alipay_dict'):
                params['sn'] = self.sn.to_alipay_dict()
            else:
                params['sn'] = self.sn
        if self.supplier_id:
            if hasattr(self.supplier_id, 'to_alipay_dict'):
                params['supplier_id'] = self.supplier_id.to_alipay_dict()
            else:
                params['supplier_id'] = self.supplier_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceAlideviceinfoOfflinecodeCreateModel()
        if 'biz_tag' in d:
            o.biz_tag = d['biz_tag']
        if 'biz_tid' in d:
            o.biz_tid = d['biz_tid']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'merchant_pid' in d:
            o.merchant_pid = d['merchant_pid']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'protocol_version' in d:
            o.protocol_version = d['protocol_version']
        if 'sn' in d:
            o.sn = d['sn']
        if 'supplier_id' in d:
            o.supplier_id = d['supplier_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AmpeDeviceModelInfo import AmpeDeviceModelInfo


class AmpeProductInfo(object):

    def __init__(self):
        self._category_desc = None
        self._category_id = None
        self._device_model_list = None
        self._device_type = None
        self._device_type_desc = None
        self._gmt_create = None
        self._gmt_modified = None
        self._invoke_app_id = None
        self._product_id = None
        self._product_name = None
        self._product_pic = None
        self._reject_memo = None
        self._ship_quantity = None
        self._status = None
        self._status_desc = None

    @property
    def category_desc(self):
        return self._category_desc

    @category_desc.setter
    def category_desc(self, value):
        self._category_desc = value
    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def device_model_list(self):
        return self._device_model_list

    @device_model_list.setter
    def device_model_list(self, value):
        if isinstance(value, list):
            self._device_model_list = list()
            for i in value:
                if isinstance(i, AmpeDeviceModelInfo):
                    self._device_model_list.append(i)
                else:
                    self._device_model_list.append(AmpeDeviceModelInfo.from_alipay_dict(i))
    @property
    def device_type(self):
        return self._device_type

    @device_type.setter
    def device_type(self, value):
        self._device_type = value
    @property
    def device_type_desc(self):
        return self._device_type_desc

    @device_type_desc.setter
    def device_type_desc(self, value):
        self._device_type_desc = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def invoke_app_id(self):
        return self._invoke_app_id

    @invoke_app_id.setter
    def invoke_app_id(self, value):
        self._invoke_app_id = value
    @property
    def product_id(self):
        return self._product_id

    @product_id.setter
    def product_id(self, value):
        self._product_id = value
    @property
    def product_name(self):
        return self._product_name

    @product_name.setter
    def product_name(self, value):
        self._product_name = value
    @property
    def product_pic(self):
        return self._product_pic

    @product_pic.setter
    def product_pic(self, value):
        self._product_pic = value
    @property
    def reject_memo(self):
        return self._reject_memo

    @reject_memo.setter
    def reject_memo(self, value):
        self._reject_memo = value
    @property
    def ship_quantity(self):
        return self._ship_quantity

    @ship_quantity.setter
    def ship_quantity(self, value):
        self._ship_quantity = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def status_desc(self):
        return self._status_desc

    @status_desc.setter
    def status_desc(self, value):
        self._status_desc = value


    def to_alipay_dict(self):
        params = dict()
        if self.category_desc:
            if hasattr(self.category_desc, 'to_alipay_dict'):
                params['category_desc'] = self.category_desc.to_alipay_dict()
            else:
                params['category_desc'] = self.category_desc
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.device_model_list:
            if isinstance(self.device_model_list, list):
                for i in range(0, len(self.device_model_list)):
                    element = self.device_model_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.device_model_list[i] = element.to_alipay_dict()
            if hasattr(self.device_model_list, 'to_alipay_dict'):
                params['device_model_list'] = self.device_model_list.to_alipay_dict()
            else:
                params['device_model_list'] = self.device_model_list
        if self.device_type:
            if hasattr(self.device_type, 'to_alipay_dict'):
                params['device_type'] = self.device_type.to_alipay_dict()
            else:
                params['device_type'] = self.device_type
        if self.device_type_desc:
            if hasattr(self.device_type_desc, 'to_alipay_dict'):
                params['device_type_desc'] = self.device_type_desc.to_alipay_dict()
            else:
                params['device_type_desc'] = self.device_type_desc
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.invoke_app_id:
            if hasattr(self.invoke_app_id, 'to_alipay_dict'):
                params['invoke_app_id'] = self.invoke_app_id.to_alipay_dict()
            else:
                params['invoke_app_id'] = self.invoke_app_id
        if self.product_id:
            if hasattr(self.product_id, 'to_alipay_dict'):
                params['product_id'] = self.product_id.to_alipay_dict()
            else:
                params['product_id'] = self.product_id
        if self.product_name:
            if hasattr(self.product_name, 'to_alipay_dict'):
                params['product_name'] = self.product_name.to_alipay_dict()
            else:
                params['product_name'] = self.product_name
        if self.product_pic:
            if hasattr(self.product_pic, 'to_alipay_dict'):
                params['product_pic'] = self.product_pic.to_alipay_dict()
            else:
                params['product_pic'] = self.product_pic
        if self.reject_memo:
            if hasattr(self.reject_memo, 'to_alipay_dict'):
                params['reject_memo'] = self.reject_memo.to_alipay_dict()
            else:
                params['reject_memo'] = self.reject_memo
        if self.ship_quantity:
            if hasattr(self.ship_quantity, 'to_alipay_dict'):
                params['ship_quantity'] = self.ship_quantity.to_alipay_dict()
            else:
                params['ship_quantity'] = self.ship_quantity
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.status_desc:
            if hasattr(self.status_desc, 'to_alipay_dict'):
                params['status_desc'] = self.status_desc.to_alipay_dict()
            else:
                params['status_desc'] = self.status_desc
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AmpeProductInfo()
        if 'category_desc' in d:
            o.category_desc = d['category_desc']
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'device_model_list' in d:
            o.device_model_list = d['device_model_list']
        if 'device_type' in d:
            o.device_type = d['device_type']
        if 'device_type_desc' in d:
            o.device_type_desc = d['device_type_desc']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'invoke_app_id' in d:
            o.invoke_app_id = d['invoke_app_id']
        if 'product_id' in d:
            o.product_id = d['product_id']
        if 'product_name' in d:
            o.product_name = d['product_name']
        if 'product_pic' in d:
            o.product_pic = d['product_pic']
        if 'reject_memo' in d:
            o.reject_memo = d['reject_memo']
        if 'ship_quantity' in d:
            o.ship_quantity = d['ship_quantity']
        if 'status' in d:
            o.status = d['status']
        if 'status_desc' in d:
            o.status_desc = d['status_desc']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsAutoServiceCouponVerifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsAutoServiceCouponVerifyResponse, self).__init__()
        self._biz_success = None

    @property
    def biz_success(self):
        return self._biz_success

    @biz_success.setter
    def biz_success(self, value):
        self._biz_success = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsAutoServiceCouponVerifyResponse, self).parse_response_content(response_content)
        if 'biz_success' in response:
            self.biz_success = response['biz_success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CplifeRoomInfo(object):

    def __init__(self):
        self._address = None
        self._building = None
        self._group = None
        self._out_room_id = None
        self._room = None
        self._unit = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def building(self):
        return self._building

    @building.setter
    def building(self, value):
        self._building = value
    @property
    def group(self):
        return self._group

    @group.setter
    def group(self, value):
        self._group = value
    @property
    def out_room_id(self):
        return self._out_room_id

    @out_room_id.setter
    def out_room_id(self, value):
        self._out_room_id = value
    @property
    def room(self):
        return self._room

    @room.setter
    def room(self, value):
        self._room = value
    @property
    def unit(self):
        return self._unit

    @unit.setter
    def unit(self, value):
        self._unit = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.building:
            if hasattr(self.building, 'to_alipay_dict'):
                params['building'] = self.building.to_alipay_dict()
            else:
                params['building'] = self.building
        if self.group:
            if hasattr(self.group, 'to_alipay_dict'):
                params['group'] = self.group.to_alipay_dict()
            else:
                params['group'] = self.group
        if self.out_room_id:
            if hasattr(self.out_room_id, 'to_alipay_dict'):
                params['out_room_id'] = self.out_room_id.to_alipay_dict()
            else:
                params['out_room_id'] = self.out_room_id
        if self.room:
            if hasattr(self.room, 'to_alipay_dict'):
                params['room'] = self.room.to_alipay_dict()
            else:
                params['room'] = self.room
        if self.unit:
            if hasattr(self.unit, 'to_alipay_dict'):
                params['unit'] = self.unit.to_alipay_dict()
            else:
                params['unit'] = self.unit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CplifeRoomInfo()
        if 'address' in d:
            o.address = d['address']
        if 'building' in d:
            o.building = d['building']
        if 'group' in d:
            o.group = d['group']
        if 'out_room_id' in d:
            o.out_room_id = d['out_room_id']
        if 'room' in d:
            o.room = d['room']
        if 'unit' in d:
            o.unit = d['unit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.IoTBPaaSDeviceApplyBindInfo import IoTBPaaSDeviceApplyBindInfo


class AlipayOpenIotbpaasDevicebindApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenIotbpaasDevicebindApplyResponse, self).__init__()
        self._bind_info = None
        self._bind_status = None
        self._bind_token = None
        self._bind_url = None

    @property
    def bind_info(self):
        return self._bind_info

    @bind_info.setter
    def bind_info(self, value):
        if isinstance(value, IoTBPaaSDeviceApplyBindInfo):
            self._bind_info = value
        else:
            self._bind_info = IoTBPaaSDeviceApplyBindInfo.from_alipay_dict(value)
    @property
    def bind_status(self):
        return self._bind_status

    @bind_status.setter
    def bind_status(self, value):
        self._bind_status = value
    @property
    def bind_token(self):
        return self._bind_token

    @bind_token.setter
    def bind_token(self, value):
        self._bind_token = value
    @property
    def bind_url(self):
        return self._bind_url

    @bind_url.setter
    def bind_url(self, value):
        self._bind_url = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenIotbpaasDevicebindApplyResponse, self).parse_response_content(response_content)
        if 'bind_info' in response:
            self.bind_info = response['bind_info']
        if 'bind_status' in response:
            self.bind_status = response['bind_status']
        if 'bind_token' in response:
            self.bind_token = response['bind_token']
        if 'bind_url' in response:
            self.bind_url = response['bind_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankPaymentTradeSubaccountCreateResponse(AlipayResponse):

    def __init__(self):
        super(MybankPaymentTradeSubaccountCreateResponse, self).__init__()
        self._account_name = None
        self._branch_name = None
        self._branch_no = None
        self._currency_value = None
        self._open_account_time = None
        self._out_channel_id = None
        self._parent_card_no = None
        self._request_no = None
        self._retry = None
        self._sub_card_no = None

    @property
    def account_name(self):
        return self._account_name

    @account_name.setter
    def account_name(self, value):
        self._account_name = value
    @property
    def branch_name(self):
        return self._branch_name

    @branch_name.setter
    def branch_name(self, value):
        self._branch_name = value
    @property
    def branch_no(self):
        return self._branch_no

    @branch_no.setter
    def branch_no(self, value):
        self._branch_no = value
    @property
    def currency_value(self):
        return self._currency_value

    @currency_value.setter
    def currency_value(self, value):
        self._currency_value = value
    @property
    def open_account_time(self):
        return self._open_account_time

    @open_account_time.setter
    def open_account_time(self, value):
        self._open_account_time = value
    @property
    def out_channel_id(self):
        return self._out_channel_id

    @out_channel_id.setter
    def out_channel_id(self, value):
        self._out_channel_id = value
    @property
    def parent_card_no(self):
        return self._parent_card_no

    @parent_card_no.setter
    def parent_card_no(self, value):
        self._parent_card_no = value
    @property
    def request_no(self):
        return self._request_no

    @request_no.setter
    def request_no(self, value):
        self._request_no = value
    @property
    def retry(self):
        return self._retry

    @retry.setter
    def retry(self, value):
        self._retry = value
    @property
    def sub_card_no(self):
        return self._sub_card_no

    @sub_card_no.setter
    def sub_card_no(self, value):
        self._sub_card_no = value

    def parse_response_content(self, response_content):
        response = super(MybankPaymentTradeSubaccountCreateResponse, self).parse_response_content(response_content)
        if 'account_name' in response:
            self.account_name = response['account_name']
        if 'branch_name' in response:
            self.branch_name = response['branch_name']
        if 'branch_no' in response:
            self.branch_no = response['branch_no']
        if 'currency_value' in response:
            self.currency_value = response['currency_value']
        if 'open_account_time' in response:
            self.open_account_time = response['open_account_time']
        if 'out_channel_id' in response:
            self.out_channel_id = response['out_channel_id']
        if 'parent_card_no' in response:
            self.parent_card_no = response['parent_card_no']
        if 'request_no' in response:
            self.request_no = response['request_no']
        if 'retry' in response:
            self.retry = response['retry']
        if 'sub_card_no' in response:
            self.sub_card_no = response['sub_card_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EnterpriseOpenRuleRelationInfo(object):

    def __init__(self):
        self._gmt_create = None
        self._gmt_modified = None
        self._owner_id = None
        self._standard_id = None

    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def owner_id(self):
        return self._owner_id

    @owner_id.setter
    def owner_id(self, value):
        self._owner_id = value
    @property
    def standard_id(self):
        return self._standard_id

    @standard_id.setter
    def standard_id(self, value):
        self._standard_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.owner_id:
            if hasattr(self.owner_id, 'to_alipay_dict'):
                params['owner_id'] = self.owner_id.to_alipay_dict()
            else:
                params['owner_id'] = self.owner_id
        if self.standard_id:
            if hasattr(self.standard_id, 'to_alipay_dict'):
                params['standard_id'] = self.standard_id.to_alipay_dict()
            else:
                params['standard_id'] = self.standard_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EnterpriseOpenRuleRelationInfo()
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'owner_id' in d:
            o.owner_id = d['owner_id']
        if 'standard_id' in d:
            o.standard_id = d['standard_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ZolozDeviceInfo import ZolozDeviceInfo


class ZolozIdentificationDeviceinfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZolozIdentificationDeviceinfoQueryResponse, self).__init__()
        self._device_info = None

    @property
    def device_info(self):
        return self._device_info

    @device_info.setter
    def device_info(self, value):
        if isinstance(value, ZolozDeviceInfo):
            self._device_info = value
        else:
            self._device_info = ZolozDeviceInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(ZolozIdentificationDeviceinfoQueryResponse, self).parse_response_content(response_content)
        if 'device_info' in response:
            self.device_info = response['device_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAppTestHahaQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppTestHahaQueryResponse, self).__init__()
        self._out_one = None
        self._out_two = None

    @property
    def out_one(self):
        return self._out_one

    @out_one.setter
    def out_one(self, value):
        self._out_one = value
    @property
    def out_two(self):
        return self._out_two

    @out_two.setter
    def out_two(self, value):
        self._out_two = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppTestHahaQueryResponse, self).parse_response_content(response_content)
        if 'out_one' in response:
            self.out_one = response['out_one']
        if 'out_two' in response:
            self.out_two = response['out_two']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.InsPolicy import InsPolicy


class AlipayInsUnderwritePolicyQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsUnderwritePolicyQueryResponse, self).__init__()
        self._policy = None

    @property
    def policy(self):
        return self._policy

    @policy.setter
    def policy(self, value):
        if isinstance(value, InsPolicy):
            self._policy = value
        else:
            self._policy = InsPolicy.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayInsUnderwritePolicyQueryResponse, self).parse_response_content(response_content)
        if 'policy' in response:
            self.policy = response['policy']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InvoiceItemApplyOpenModel(object):

    def __init__(self):
        self._item_ex_tax_amount = None
        self._item_name = None
        self._item_no = None
        self._item_quantity = None
        self._item_spec = None
        self._item_sum_amount = None
        self._item_tax_amount = None
        self._item_tax_rate = None
        self._item_unit = None
        self._item_unit_price = None
        self._prefer_policy_flag = None
        self._row_type = None
        self._special_manage_flag = None
        self._zero_tax_flag = None

    @property
    def item_ex_tax_amount(self):
        return self._item_ex_tax_amount

    @item_ex_tax_amount.setter
    def item_ex_tax_amount(self, value):
        self._item_ex_tax_amount = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def item_no(self):
        return self._item_no

    @item_no.setter
    def item_no(self, value):
        self._item_no = value
    @property
    def item_quantity(self):
        return self._item_quantity

    @item_quantity.setter
    def item_quantity(self, value):
        self._item_quantity = value
    @property
    def item_spec(self):
        return self._item_spec

    @item_spec.setter
    def item_spec(self, value):
        self._item_spec = value
    @property
    def item_sum_amount(self):
        return self._item_sum_amount

    @item_sum_amount.setter
    def item_sum_amount(self, value):
        self._item_sum_amount = value
    @property
    def item_tax_amount(self):
        return self._item_tax_amount

    @item_tax_amount.setter
    def item_tax_amount(self, value):
        self._item_tax_amount = value
    @property
    def item_tax_rate(self):
        return self._item_tax_rate

    @item_tax_rate.setter
    def item_tax_rate(self, value):
        self._item_tax_rate = value
    @property
    def item_unit(self):
        return self._item_unit

    @item_unit.setter
    def item_unit(self, value):
        self._item_unit = value
    @property
    def item_unit_price(self):
        return self._item_unit_price

    @item_unit_price.setter
    def item_unit_price(self, value):
        self._item_unit_price = value
    @property
    def prefer_policy_flag(self):
        return self._prefer_policy_flag

    @prefer_policy_flag.setter
    def prefer_policy_flag(self, value):
        self._prefer_policy_flag = value
    @property
    def row_type(self):
        return self._row_type

    @row_type.setter
    def row_type(self, value):
        self._row_type = value
    @property
    def special_manage_flag(self):
        return self._special_manage_flag

    @special_manage_flag.setter
    def special_manage_flag(self, value):
        self._special_manage_flag = value
    @property
    def zero_tax_flag(self):
        return self._zero_tax_flag

    @zero_tax_flag.setter
    def zero_tax_flag(self, value):
        self._zero_tax_flag = value


    def to_alipay_dict(self):
        params = dict()
        if self.item_ex_tax_amount:
            if hasattr(self.item_ex_tax_amount, 'to_alipay_dict'):
                params['item_ex_tax_amount'] = self.item_ex_tax_amount.to_alipay_dict()
            else:
                params['item_ex_tax_amount'] = self.item_ex_tax_amount
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.item_no:
            if hasattr(self.item_no, 'to_alipay_dict'):
                params['item_no'] = self.item_no.to_alipay_dict()
            else:
                params['item_no'] = self.item_no
        if self.item_quantity:
            if hasattr(self.item_quantity, 'to_alipay_dict'):
                params['item_quantity'] = self.item_quantity.to_alipay_dict()
            else:
                params['item_quantity'] = self.item_quantity
        if self.item_spec:
            if hasattr(self.item_spec, 'to_alipay_dict'):
                params['item_spec'] = self.item_spec.to_alipay_dict()
            else:
                params['item_spec'] = self.item_spec
        if self.item_sum_amount:
            if hasattr(self.item_sum_amount, 'to_alipay_dict'):
                params['item_sum_amount'] = self.item_sum_amount.to_alipay_dict()
            else:
                params['item_sum_amount'] = self.item_sum_amount
        if self.item_tax_amount:
            if hasattr(self.item_tax_amount, 'to_alipay_dict'):
                params['item_tax_amount'] = self.item_tax_amount.to_alipay_dict()
            else:
                params['item_tax_amount'] = self.item_tax_amount
        if self.item_tax_rate:
            if hasattr(self.item_tax_rate, 'to_alipay_dict'):
                params['item_tax_rate'] = self.item_tax_rate.to_alipay_dict()
            else:
                params['item_tax_rate'] = self.item_tax_rate
        if self.item_unit:
            if hasattr(self.item_unit, 'to_alipay_dict'):
                params['item_unit'] = self.item_unit.to_alipay_dict()
            else:
                params['item_unit'] = self.item_unit
        if self.item_unit_price:
            if hasattr(self.item_unit_price, 'to_alipay_dict'):
                params['item_unit_price'] = self.item_unit_price.to_alipay_dict()
            else:
                params['item_unit_price'] = self.item_unit_price
        if self.prefer_policy_flag:
            if hasattr(self.prefer_policy_flag, 'to_alipay_dict'):
                params['prefer_policy_flag'] = self.prefer_policy_flag.to_alipay_dict()
            else:
                params['prefer_policy_flag'] = self.prefer_policy_flag
        if self.row_type:
            if hasattr(self.row_type, 'to_alipay_dict'):
                params['row_type'] = self.row_type.to_alipay_dict()
            else:
                params['row_type'] = self.row_type
        if self.special_manage_flag:
            if hasattr(self.special_manage_flag, 'to_alipay_dict'):
                params['special_manage_flag'] = self.special_manage_flag.to_alipay_dict()
            else:
                params['special_manage_flag'] = self.special_manage_flag
        if self.zero_tax_flag:
            if hasattr(self.zero_tax_flag, 'to_alipay_dict'):
                params['zero_tax_flag'] = self.zero_tax_flag.to_alipay_dict()
            else:
                params['zero_tax_flag'] = self.zero_tax_flag
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InvoiceItemApplyOpenModel()
        if 'item_ex_tax_amount' in d:
            o.item_ex_tax_amount = d['item_ex_tax_amount']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'item_no' in d:
            o.item_no = d['item_no']
        if 'item_quantity' in d:
            o.item_quantity = d['item_quantity']
        if 'item_spec' in d:
            o.item_spec = d['item_spec']
        if 'item_sum_amount' in d:
            o.item_sum_amount = d['item_sum_amount']
        if 'item_tax_amount' in d:
            o.item_tax_amount = d['item_tax_amount']
        if 'item_tax_rate' in d:
            o.item_tax_rate = d['item_tax_rate']
        if 'item_unit' in d:
            o.item_unit = d['item_unit']
        if 'item_unit_price' in d:
            o.item_unit_price = d['item_unit_price']
        if 'prefer_policy_flag' in d:
            o.prefer_policy_flag = d['prefer_policy_flag']
        if 'row_type' in d:
            o.row_type = d['row_type']
        if 'special_manage_flag' in d:
            o.special_manage_flag = d['special_manage_flag']
        if 'zero_tax_flag' in d:
            o.zero_tax_flag = d['zero_tax_flag']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MsgContent(object):

    def __init__(self):
        self._content_timestamp = None
        self._content_type = None

    @property
    def content_timestamp(self):
        return self._content_timestamp

    @content_timestamp.setter
    def content_timestamp(self, value):
        self._content_timestamp = value
    @property
    def content_type(self):
        return self._content_type

    @content_type.setter
    def content_type(self, value):
        self._content_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.content_timestamp:
            if hasattr(self.content_timestamp, 'to_alipay_dict'):
                params['content_timestamp'] = self.content_timestamp.to_alipay_dict()
            else:
                params['content_timestamp'] = self.content_timestamp
        if self.content_type:
            if hasattr(self.content_type, 'to_alipay_dict'):
                params['content_type'] = self.content_type.to_alipay_dict()
            else:
                params['content_type'] = self.content_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MsgContent()
        if 'content_timestamp' in d:
            o.content_timestamp = d['content_timestamp']
        if 'content_type' in d:
            o.content_type = d['content_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InstCashPoolAllocationRuleVO import InstCashPoolAllocationRuleVO


class AlipayAccountCashpoolAllocateruleCreateModel(object):

    def __init__(self):
        self._allocation_rule = None
        self._cash_pool_id = None
        self._operator = None
        self._rule_group_id = None

    @property
    def allocation_rule(self):
        return self._allocation_rule

    @allocation_rule.setter
    def allocation_rule(self, value):
        if isinstance(value, InstCashPoolAllocationRuleVO):
            self._allocation_rule = value
        else:
            self._allocation_rule = InstCashPoolAllocationRuleVO.from_alipay_dict(value)
    @property
    def cash_pool_id(self):
        return self._cash_pool_id

    @cash_pool_id.setter
    def cash_pool_id(self, value):
        self._cash_pool_id = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def rule_group_id(self):
        return self._rule_group_id

    @rule_group_id.setter
    def rule_group_id(self, value):
        self._rule_group_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.allocation_rule:
            if hasattr(self.allocation_rule, 'to_alipay_dict'):
                params['allocation_rule'] = self.allocation_rule.to_alipay_dict()
            else:
                params['allocation_rule'] = self.allocation_rule
        if self.cash_pool_id:
            if hasattr(self.cash_pool_id, 'to_alipay_dict'):
                params['cash_pool_id'] = self.cash_pool_id.to_alipay_dict()
            else:
                params['cash_pool_id'] = self.cash_pool_id
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.rule_group_id:
            if hasattr(self.rule_group_id, 'to_alipay_dict'):
                params['rule_group_id'] = self.rule_group_id.to_alipay_dict()
            else:
                params['rule_group_id'] = self.rule_group_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayAccountCashpoolAllocateruleCreateModel()
        if 'allocation_rule' in d:
            o.allocation_rule = d['allocation_rule']
        if 'cash_pool_id' in d:
            o.cash_pool_id = d['cash_pool_id']
        if 'operator' in d:
            o.operator = d['operator']
        if 'rule_group_id' in d:
            o.rule_group_id = d['rule_group_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AuthFieldDTO(object):

    def __init__(self):
        self._api_name = None
        self._field_name = None
        self._package_code = None
        self._reason = None
        self._status = None
        self._user_app_id = None

    @property
    def api_name(self):
        return self._api_name

    @api_name.setter
    def api_name(self, value):
        self._api_name = value
    @property
    def field_name(self):
        return self._field_name

    @field_name.setter
    def field_name(self, value):
        self._field_name = value
    @property
    def package_code(self):
        return self._package_code

    @package_code.setter
    def package_code(self, value):
        self._package_code = value
    @property
    def reason(self):
        return self._reason

    @reason.setter
    def reason(self, value):
        self._reason = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def user_app_id(self):
        return self._user_app_id

    @user_app_id.setter
    def user_app_id(self, value):
        self._user_app_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.api_name:
            if hasattr(self.api_name, 'to_alipay_dict'):
                params['api_name'] = self.api_name.to_alipay_dict()
            else:
                params['api_name'] = self.api_name
        if self.field_name:
            if hasattr(self.field_name, 'to_alipay_dict'):
                params['field_name'] = self.field_name.to_alipay_dict()
            else:
                params['field_name'] = self.field_name
        if self.package_code:
            if hasattr(self.package_code, 'to_alipay_dict'):
                params['package_code'] = self.package_code.to_alipay_dict()
            else:
                params['package_code'] = self.package_code
        if self.reason:
            if hasattr(self.reason, 'to_alipay_dict'):
                params['reason'] = self.reason.to_alipay_dict()
            else:
                params['reason'] = self.reason
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.user_app_id:
            if hasattr(self.user_app_id, 'to_alipay_dict'):
                params['user_app_id'] = self.user_app_id.to_alipay_dict()
            else:
                params['user_app_id'] = self.user_app_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AuthFieldDTO()
        if 'api_name' in d:
            o.api_name = d['api_name']
        if 'field_name' in d:
            o.field_name = d['field_name']
        if 'package_code' in d:
            o.package_code = d['package_code']
        if 'reason' in d:
            o.reason = d['reason']
        if 'status' in d:
            o.status = d['status']
        if 'user_app_id' in d:
            o.user_app_id = d['user_app_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CertAvailableNumVO(object):

    def __init__(self):
        self._available_num = None
        self._cert_template_id = None

    @property
    def available_num(self):
        return self._available_num

    @available_num.setter
    def available_num(self, value):
        self._available_num = value
    @property
    def cert_template_id(self):
        return self._cert_template_id

    @cert_template_id.setter
    def cert_template_id(self, value):
        self._cert_template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.available_num:
            if hasattr(self.available_num, 'to_alipay_dict'):
                params['available_num'] = self.available_num.to_alipay_dict()
            else:
                params['available_num'] = self.available_num
        if self.cert_template_id:
            if hasattr(self.cert_template_id, 'to_alipay_dict'):
                params['cert_template_id'] = self.cert_template_id.to_alipay_dict()
            else:
                params['cert_template_id'] = self.cert_template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CertAvailableNumVO()
        if 'available_num' in d:
            o.available_num = d['available_num']
        if 'cert_template_id' in d:
            o.cert_template_id = d['cert_template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DetailBean(object):

    def __init__(self):
        self._code = None
        self._description = None
        self._order = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def order(self):
        return self._order

    @order.setter
    def order(self, value):
        self._order = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.order:
            if hasattr(self.order, 'to_alipay_dict'):
                params['order'] = self.order.to_alipay_dict()
            else:
                params['order'] = self.order
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DetailBean()
        if 'code' in d:
            o.code = d['code']
        if 'description' in d:
            o.description = d['description']
        if 'order' in d:
            o.order = d['order']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityProdMyGetchyQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityProdMyGetchyQueryResponse, self).__init__()
        self._chen = None

    @property
    def chen(self):
        return self._chen

    @chen.setter
    def chen(self, value):
        self._chen = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityProdMyGetchyQueryResponse, self).parse_response_content(response_content)
        if 'chen' in response:
            self.chen = response['chen']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CCInfo(object):

    def __init__(self):
        self._address = None
        self._cc_ext = None
        self._cr_code = None
        self._cr_desc = None
        self._email = None
        self._item_alias_name = None
        self._item_desc = None
        self._item_id = None
        self._item_name = None
        self._quantity = None
        self._recipient_entity_name = None
        self._recipient_name = None
        self._recipient_phone = None
        self._unit_price = None
        self._zip_code = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def cc_ext(self):
        return self._cc_ext

    @cc_ext.setter
    def cc_ext(self, value):
        self._cc_ext = value
    @property
    def cr_code(self):
        return self._cr_code

    @cr_code.setter
    def cr_code(self, value):
        self._cr_code = value
    @property
    def cr_desc(self):
        return self._cr_desc

    @cr_desc.setter
    def cr_desc(self, value):
        self._cr_desc = value
    @property
    def email(self):
        return self._email

    @email.setter
    def email(self, value):
        self._email = value
    @property
    def item_alias_name(self):
        return self._item_alias_name

    @item_alias_name.setter
    def item_alias_name(self, value):
        self._item_alias_name = value
    @property
    def item_desc(self):
        return self._item_desc

    @item_desc.setter
    def item_desc(self, value):
        self._item_desc = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def quantity(self):
        return self._quantity

    @quantity.setter
    def quantity(self, value):
        self._quantity = value
    @property
    def recipient_entity_name(self):
        return self._recipient_entity_name

    @recipient_entity_name.setter
    def recipient_entity_name(self, value):
        self._recipient_entity_name = value
    @property
    def recipient_name(self):
        return self._recipient_name

    @recipient_name.setter
    def recipient_name(self, value):
        self._recipient_name = value
    @property
    def recipient_phone(self):
        return self._recipient_phone

    @recipient_phone.setter
    def recipient_phone(self, value):
        self._recipient_phone = value
    @property
    def unit_price(self):
        return self._unit_price

    @unit_price.setter
    def unit_price(self, value):
        self._unit_price = value
    @property
    def zip_code(self):
        return self._zip_code

    @zip_code.setter
    def zip_code(self, value):
        self._zip_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.cc_ext:
            if hasattr(self.cc_ext, 'to_alipay_dict'):
                params['cc_ext'] = self.cc_ext.to_alipay_dict()
            else:
                params['cc_ext'] = self.cc_ext
        if self.cr_code:
            if hasattr(self.cr_code, 'to_alipay_dict'):
                params['cr_code'] = self.cr_code.to_alipay_dict()
            else:
                params['cr_code'] = self.cr_code
        if self.cr_desc:
            if hasattr(self.cr_desc, 'to_alipay_dict'):
                params['cr_desc'] = self.cr_desc.to_alipay_dict()
            else:
                params['cr_desc'] = self.cr_desc
        if self.email:
            if hasattr(self.email, 'to_alipay_dict'):
                params['email'] = self.email.to_alipay_dict()
            else:
                params['email'] = self.email
        if self.item_alias_name:
            if hasattr(self.item_alias_name, 'to_alipay_dict'):
                params['item_alias_name'] = self.item_alias_name.to_alipay_dict()
            else:
                params['item_alias_name'] = self.item_alias_name
        if self.item_desc:
            if hasattr(self.item_desc, 'to_alipay_dict'):
                params['item_desc'] = self.item_desc.to_alipay_dict()
            else:
                params['item_desc'] = self.item_desc
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.quantity:
            if hasattr(self.quantity, 'to_alipay_dict'):
                params['quantity'] = self.quantity.to_alipay_dict()
            else:
                params['quantity'] = self.quantity
        if self.recipient_entity_name:
            if hasattr(self.recipient_entity_name, 'to_alipay_dict'):
                params['recipient_entity_name'] = self.recipient_entity_name.to_alipay_dict()
            else:
                params['recipient_entity_name'] = self.recipient_entity_name
        if self.recipient_name:
            if hasattr(self.recipient_name, 'to_alipay_dict'):
                params['recipient_name'] = self.recipient_name.to_alipay_dict()
            else:
                params['recipient_name'] = self.recipient_name
        if self.recipient_phone:
            if hasattr(self.recipient_phone, 'to_alipay_dict'):
                params['recipient_phone'] = self.recipient_phone.to_alipay_dict()
            else:
                params['recipient_phone'] = self.recipient_phone
        if self.unit_price:
            if hasattr(self.unit_price, 'to_alipay_dict'):
                params['unit_price'] = self.unit_price.to_alipay_dict()
            else:
                params['unit_price'] = self.unit_price
        if self.zip_code:
            if hasattr(self.zip_code, 'to_alipay_dict'):
                params['zip_code'] = self.zip_code.to_alipay_dict()
            else:
                params['zip_code'] = self.zip_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CCInfo()
        if 'address' in d:
            o.address = d['address']
        if 'cc_ext' in d:
            o.cc_ext = d['cc_ext']
        if 'cr_code' in d:
            o.cr_code = d['cr_code']
        if 'cr_desc' in d:
            o.cr_desc = d['cr_desc']
        if 'email' in d:
            o.email = d['email']
        if 'item_alias_name' in d:
            o.item_alias_name = d['item_alias_name']
        if 'item_desc' in d:
            o.item_desc = d['item_desc']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'quantity' in d:
            o.quantity = d['quantity']
        if 'recipient_entity_name' in d:
            o.recipient_entity_name = d['recipient_entity_name']
        if 'recipient_name' in d:
            o.recipient_name = d['recipient_name']
        if 'recipient_phone' in d:
            o.recipient_phone = d['recipient_phone']
        if 'unit_price' in d:
            o.unit_price = d['unit_price']
        if 'zip_code' in d:
            o.zip_code = d['zip_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenSearchBoxactivityBatchqueryModel(object):

    def __init__(self):
        self._box_id = None
        self._merchant_id = None
        self._page_number = None
        self._page_size = None

    @property
    def box_id(self):
        return self._box_id

    @box_id.setter
    def box_id(self, value):
        self._box_id = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def page_number(self):
        return self._page_number

    @page_number.setter
    def page_number(self, value):
        self._page_number = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value


    def to_alipay_dict(self):
        params = dict()
        if self.box_id:
            if hasattr(self.box_id, 'to_alipay_dict'):
                params['box_id'] = self.box_id.to_alipay_dict()
            else:
                params['box_id'] = self.box_id
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.page_number:
            if hasattr(self.page_number, 'to_alipay_dict'):
                params['page_number'] = self.page_number.to_alipay_dict()
            else:
                params['page_number'] = self.page_number
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenSearchBoxactivityBatchqueryModel()
        if 'box_id' in d:
            o.box_id = d['box_id']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'page_number' in d:
            o.page_number = d['page_number']
        if 'page_size' in d:
            o.page_size = d['page_size']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MpPrizeInfoModel(object):

    def __init__(self):
        self._certlot_number = None
        self._frequency_count = None
        self._frequency_type = None
        self._prize_end_time = None
        self._prize_id = None
        self._prize_max_award_limit = None
        self._prize_name = None
        self._prize_start_time = None
        self._prize_total = None
        self._prize_type = None

    @property
    def certlot_number(self):
        return self._certlot_number

    @certlot_number.setter
    def certlot_number(self, value):
        self._certlot_number = value
    @property
    def frequency_count(self):
        return self._frequency_count

    @frequency_count.setter
    def frequency_count(self, value):
        self._frequency_count = value
    @property
    def frequency_type(self):
        return self._frequency_type

    @frequency_type.setter
    def frequency_type(self, value):
        self._frequency_type = value
    @property
    def prize_end_time(self):
        return self._prize_end_time

    @prize_end_time.setter
    def prize_end_time(self, value):
        self._prize_end_time = value
    @property
    def prize_id(self):
        return self._prize_id

    @prize_id.setter
    def prize_id(self, value):
        self._prize_id = value
    @property
    def prize_max_award_limit(self):
        return self._prize_max_award_limit

    @prize_max_award_limit.setter
    def prize_max_award_limit(self, value):
        self._prize_max_award_limit = value
    @property
    def prize_name(self):
        return self._prize_name

    @prize_name.setter
    def prize_name(self, value):
        self._prize_name = value
    @property
    def prize_start_time(self):
        return self._prize_start_time

    @prize_start_time.setter
    def prize_start_time(self, value):
        self._prize_start_time = value
    @property
    def prize_total(self):
        return self._prize_total

    @prize_total.setter
    def prize_total(self, value):
        self._prize_total = value
    @property
    def prize_type(self):
        return self._prize_type

    @prize_type.setter
    def prize_type(self, value):
        self._prize_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.certlot_number:
            if hasattr(self.certlot_number, 'to_alipay_dict'):
                params['certlot_number'] = self.certlot_number.to_alipay_dict()
            else:
                params['certlot_number'] = self.certlot_number
        if self.frequency_count:
            if hasattr(self.frequency_count, 'to_alipay_dict'):
                params['frequency_count'] = self.frequency_count.to_alipay_dict()
            else:
                params['frequency_count'] = self.frequency_count
        if self.frequency_type:
            if hasattr(self.frequency_type, 'to_alipay_dict'):
                params['frequency_type'] = self.frequency_type.to_alipay_dict()
            else:
                params['frequency_type'] = self.frequency_type
        if self.prize_end_time:
            if hasattr(self.prize_end_time, 'to_alipay_dict'):
                params['prize_end_time'] = self.prize_end_time.to_alipay_dict()
            else:
                params['prize_end_time'] = self.prize_end_time
        if self.prize_id:
            if hasattr(self.prize_id, 'to_alipay_dict'):
                params['prize_id'] = self.prize_id.to_alipay_dict()
            else:
                params['prize_id'] = self.prize_id
        if self.prize_max_award_limit:
            if hasattr(self.prize_max_award_limit, 'to_alipay_dict'):
                params['prize_max_award_limit'] = self.prize_max_award_limit.to_alipay_dict()
            else:
                params['prize_max_award_limit'] = self.prize_max_award_limit
        if self.prize_name:
            if hasattr(self.prize_name, 'to_alipay_dict'):
                params['prize_name'] = self.prize_name.to_alipay_dict()
            else:
                params['prize_name'] = self.prize_name
        if self.prize_start_time:
            if hasattr(self.prize_start_time, 'to_alipay_dict'):
                params['prize_start_time'] = self.prize_start_time.to_alipay_dict()
            else:
                params['prize_start_time'] = self.prize_start_time
        if self.prize_total:
            if hasattr(self.prize_total, 'to_alipay_dict'):
                params['prize_total'] = self.prize_total.to_alipay_dict()
            else:
                params['prize_total'] = self.prize_total
        if self.prize_type:
            if hasattr(self.prize_type, 'to_alipay_dict'):
                params['prize_type'] = self.prize_type.to_alipay_dict()
            else:
                params['prize_type'] = self.prize_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MpPrizeInfoModel()
        if 'certlot_number' in d:
            o.certlot_number = d['certlot_number']
        if 'frequency_count' in d:
            o.frequency_count = d['frequency_count']
        if 'frequency_type' in d:
            o.frequency_type = d['frequency_type']
        if 'prize_end_time' in d:
            o.prize_end_time = d['prize_end_time']
        if 'prize_id' in d:
            o.prize_id = d['prize_id']
        if 'prize_max_award_limit' in d:
            o.prize_max_award_limit = d['prize_max_award_limit']
        if 'prize_name' in d:
            o.prize_name = d['prize_name']
        if 'prize_start_time' in d:
            o.prize_start_time = d['prize_start_time']
        if 'prize_total' in d:
            o.prize_total = d['prize_total']
        if 'prize_type' in d:
            o.prize_type = d['prize_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportWorldCardscriptQueryModel(object):

    def __init__(self):
        self._script_name = None
        self._script_type = None

    @property
    def script_name(self):
        return self._script_name

    @script_name.setter
    def script_name(self, value):
        self._script_name = value
    @property
    def script_type(self):
        return self._script_type

    @script_type.setter
    def script_type(self, value):
        self._script_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.script_name:
            if hasattr(self.script_name, 'to_alipay_dict'):
                params['script_name'] = self.script_name.to_alipay_dict()
            else:
                params['script_name'] = self.script_name
        if self.script_type:
            if hasattr(self.script_type, 'to_alipay_dict'):
                params['script_type'] = self.script_type.to_alipay_dict()
            else:
                params['script_type'] = self.script_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportWorldCardscriptQueryModel()
        if 'script_name' in d:
            o.script_name = d['script_name']
        if 'script_type' in d:
            o.script_type = d['script_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DeviceProductInfo import DeviceProductInfo


class InvokeAppInfo(object):

    def __init__(self):
        self._invoke_app_id = None
        self._invoke_app_logo = None
        self._invoke_app_name = None
        self._related_product_list = None

    @property
    def invoke_app_id(self):
        return self._invoke_app_id

    @invoke_app_id.setter
    def invoke_app_id(self, value):
        self._invoke_app_id = value
    @property
    def invoke_app_logo(self):
        return self._invoke_app_logo

    @invoke_app_logo.setter
    def invoke_app_logo(self, value):
        self._invoke_app_logo = value
    @property
    def invoke_app_name(self):
        return self._invoke_app_name

    @invoke_app_name.setter
    def invoke_app_name(self, value):
        self._invoke_app_name = value
    @property
    def related_product_list(self):
        return self._related_product_list

    @related_product_list.setter
    def related_product_list(self, value):
        if isinstance(value, list):
            self._related_product_list = list()
            for i in value:
                if isinstance(i, DeviceProductInfo):
                    self._related_product_list.append(i)
                else:
                    self._related_product_list.append(DeviceProductInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.invoke_app_id:
            if hasattr(self.invoke_app_id, 'to_alipay_dict'):
                params['invoke_app_id'] = self.invoke_app_id.to_alipay_dict()
            else:
                params['invoke_app_id'] = self.invoke_app_id
        if self.invoke_app_logo:
            if hasattr(self.invoke_app_logo, 'to_alipay_dict'):
                params['invoke_app_logo'] = self.invoke_app_logo.to_alipay_dict()
            else:
                params['invoke_app_logo'] = self.invoke_app_logo
        if self.invoke_app_name:
            if hasattr(self.invoke_app_name, 'to_alipay_dict'):
                params['invoke_app_name'] = self.invoke_app_name.to_alipay_dict()
            else:
                params['invoke_app_name'] = self.invoke_app_name
        if self.related_product_list:
            if isinstance(self.related_product_list, list):
                for i in range(0, len(self.related_product_list)):
                    element = self.related_product_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.related_product_list[i] = element.to_alipay_dict()
            if hasattr(self.related_product_list, 'to_alipay_dict'):
                params['related_product_list'] = self.related_product_list.to_alipay_dict()
            else:
                params['related_product_list'] = self.related_product_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InvokeAppInfo()
        if 'invoke_app_id' in d:
            o.invoke_app_id = d['invoke_app_id']
        if 'invoke_app_logo' in d:
            o.invoke_app_logo = d['invoke_app_logo']
        if 'invoke_app_name' in d:
            o.invoke_app_name = d['invoke_app_name']
        if 'related_product_list' in d:
            o.related_product_list = d['related_product_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataDataexchangeDtmorseSyncModel(object):

    def __init__(self):
        self._data = None
        self._extent_info = None
        self._mid = None
        self._operate_type = None

    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        self._data = value
    @property
    def extent_info(self):
        return self._extent_info

    @extent_info.setter
    def extent_info(self, value):
        self._extent_info = value
    @property
    def mid(self):
        return self._mid

    @mid.setter
    def mid(self, value):
        self._mid = value
    @property
    def operate_type(self):
        return self._operate_type

    @operate_type.setter
    def operate_type(self, value):
        self._operate_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.data:
            if hasattr(self.data, 'to_alipay_dict'):
                params['data'] = self.data.to_alipay_dict()
            else:
                params['data'] = self.data
        if self.extent_info:
            if hasattr(self.extent_info, 'to_alipay_dict'):
                params['extent_info'] = self.extent_info.to_alipay_dict()
            else:
                params['extent_info'] = self.extent_info
        if self.mid:
            if hasattr(self.mid, 'to_alipay_dict'):
                params['mid'] = self.mid.to_alipay_dict()
            else:
                params['mid'] = self.mid
        if self.operate_type:
            if hasattr(self.operate_type, 'to_alipay_dict'):
                params['operate_type'] = self.operate_type.to_alipay_dict()
            else:
                params['operate_type'] = self.operate_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataDataexchangeDtmorseSyncModel()
        if 'data' in d:
            o.data = d['data']
        if 'extent_info' in d:
            o.extent_info = d['extent_info']
        if 'mid' in d:
            o.mid = d['mid']
        if 'operate_type' in d:
            o.operate_type = d['operate_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CommonPrizeModelVo import CommonPrizeModelVo


class AlipayFundCouponWufuLiveAcceptResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundCouponWufuLiveAcceptResponse, self).__init__()
        self._prize_list = None
        self._prized = None

    @property
    def prize_list(self):
        return self._prize_list

    @prize_list.setter
    def prize_list(self, value):
        if isinstance(value, list):
            self._prize_list = list()
            for i in value:
                if isinstance(i, CommonPrizeModelVo):
                    self._prize_list.append(i)
                else:
                    self._prize_list.append(CommonPrizeModelVo.from_alipay_dict(i))
    @property
    def prized(self):
        return self._prized

    @prized.setter
    def prized(self, value):
        self._prized = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundCouponWufuLiveAcceptResponse, self).parse_response_content(response_content)
        if 'prize_list' in response:
            self.prize_list = response['prize_list']
        if 'prized' in response:
            self.prized = response['prized']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceEducateFacepayApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEducateFacepayApplyResponse, self).__init__()
        self._apply_token = None
        self._face_uid = None
        self._school_stdcode = None

    @property
    def apply_token(self):
        return self._apply_token

    @apply_token.setter
    def apply_token(self, value):
        self._apply_token = value
    @property
    def face_uid(self):
        return self._face_uid

    @face_uid.setter
    def face_uid(self, value):
        self._face_uid = value
    @property
    def school_stdcode(self):
        return self._school_stdcode

    @school_stdcode.setter
    def school_stdcode(self, value):
        self._school_stdcode = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEducateFacepayApplyResponse, self).parse_response_content(response_content)
        if 'apply_token' in response:
            self.apply_token = response['apply_token']
        if 'face_uid' in response:
            self.face_uid = response['face_uid']
        if 'school_stdcode' in response:
            self.school_stdcode = response['school_stdcode']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiServindustryNatatoriumWaterqualityUploadModel(object):

    def __init__(self):
        self._commodity_id = None
        self._current_num = None
        self._currentnum_update_time = None
        self._external_id = None
        self._footpool_cl_qualified = None
        self._footpool_cl_remain = None
        self._footpool_cl_remain_standard = None
        self._limit_num = None
        self._mainpool_cl_qualified = None
        self._mainpool_cl_remain = None
        self._mainpool_cl_remain_standard = None
        self._pool_volume = None
        self._remark = None
        self._request_id = None
        self._shop_id = None
        self._water_change = None
        self._water_change_percent = None
        self._water_change_qualified = None
        self._water_change_standard = None
        self._water_check_time = None
        self._water_ph = None
        self._water_ph_qualified = None
        self._water_ph_standard = None
        self._water_qualified = None
        self._water_temperature = None
        self._water_temperature_qualified = None
        self._water_temperature_standard = None
        self._water_update_time = None

    @property
    def commodity_id(self):
        return self._commodity_id

    @commodity_id.setter
    def commodity_id(self, value):
        self._commodity_id = value
    @property
    def current_num(self):
        return self._current_num

    @current_num.setter
    def current_num(self, value):
        self._current_num = value
    @property
    def currentnum_update_time(self):
        return self._currentnum_update_time

    @currentnum_update_time.setter
    def currentnum_update_time(self, value):
        self._currentnum_update_time = value
    @property
    def external_id(self):
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        self._external_id = value
    @property
    def footpool_cl_qualified(self):
        return self._footpool_cl_qualified

    @footpool_cl_qualified.setter
    def footpool_cl_qualified(self, value):
        self._footpool_cl_qualified = value
    @property
    def footpool_cl_remain(self):
        return self._footpool_cl_remain

    @footpool_cl_remain.setter
    def footpool_cl_remain(self, value):
        self._footpool_cl_remain = value
    @property
    def footpool_cl_remain_standard(self):
        return self._footpool_cl_remain_standard

    @footpool_cl_remain_standard.setter
    def footpool_cl_remain_standard(self, value):
        self._footpool_cl_remain_standard = value
    @property
    def limit_num(self):
        return self._limit_num

    @limit_num.setter
    def limit_num(self, value):
        self._limit_num = value
    @property
    def mainpool_cl_qualified(self):
        return self._mainpool_cl_qualified

    @mainpool_cl_qualified.setter
    def mainpool_cl_qualified(self, value):
        self._mainpool_cl_qualified = value
    @property
    def mainpool_cl_remain(self):
        return self._mainpool_cl_remain

    @mainpool_cl_remain.setter
    def mainpool_cl_remain(self, value):
        self._mainpool_cl_remain = value
    @property
    def mainpool_cl_remain_standard(self):
        return self._mainpool_cl_remain_standard

    @mainpool_cl_remain_standard.setter
    def mainpool_cl_remain_standard(self, value):
        self._mainpool_cl_remain_standard = value
    @property
    def pool_volume(self):
        return self._pool_volume

    @pool_volume.setter
    def pool_volume(self, value):
        self._pool_volume = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def water_change(self):
        return self._water_change

    @water_change.setter
    def water_change(self, value):
        self._water_change = value
    @property
    def water_change_percent(self):
        return self._water_change_percent

    @water_change_percent.setter
    def water_change_percent(self, value):
        self._water_change_percent = value
    @property
    def water_change_qualified(self):
        return self._water_change_qualified

    @water_change_qualified.setter
    def water_change_qualified(self, value):
        self._water_change_qualified = value
    @property
    def water_change_standard(self):
        return self._water_change_standard

    @water_change_standard.setter
    def water_change_standard(self, value):
        self._water_change_standard = value
    @property
    def water_check_time(self):
        return self._water_check_time

    @water_check_time.setter
    def water_check_time(self, value):
        self._water_check_time = value
    @property
    def water_ph(self):
        return self._water_ph

    @water_ph.setter
    def water_ph(self, value):
        self._water_ph = value
    @property
    def water_ph_qualified(self):
        return self._water_ph_qualified

    @water_ph_qualified.setter
    def water_ph_qualified(self, value):
        self._water_ph_qualified = value
    @property
    def water_ph_standard(self):
        return self._water_ph_standard

    @water_ph_standard.setter
    def water_ph_standard(self, value):
        self._water_ph_standard = value
    @property
    def water_qualified(self):
        return self._water_qualified

    @water_qualified.setter
    def water_qualified(self, value):
        self._water_qualified = value
    @property
    def water_temperature(self):
        return self._water_temperature

    @water_temperature.setter
    def water_temperature(self, value):
        self._water_temperature = value
    @property
    def water_temperature_qualified(self):
        return self._water_temperature_qualified

    @water_temperature_qualified.setter
    def water_temperature_qualified(self, value):
        self._water_temperature_qualified = value
    @property
    def water_temperature_standard(self):
        return self._water_temperature_standard

    @water_temperature_standard.setter
    def water_temperature_standard(self, value):
        self._water_temperature_standard = value
    @property
    def water_update_time(self):
        return self._water_update_time

    @water_update_time.setter
    def water_update_time(self, value):
        self._water_update_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.commodity_id:
            if hasattr(self.commodity_id, 'to_alipay_dict'):
                params['commodity_id'] = self.commodity_id.to_alipay_dict()
            else:
                params['commodity_id'] = self.commodity_id
        if self.current_num:
            if hasattr(self.current_num, 'to_alipay_dict'):
                params['current_num'] = self.current_num.to_alipay_dict()
            else:
                params['current_num'] = self.current_num
        if self.currentnum_update_time:
            if hasattr(self.currentnum_update_time, 'to_alipay_dict'):
                params['currentnum_update_time'] = self.currentnum_update_time.to_alipay_dict()
            else:
                params['currentnum_update_time'] = self.currentnum_update_time
        if self.external_id:
            if hasattr(self.external_id, 'to_alipay_dict'):
                params['external_id'] = self.external_id.to_alipay_dict()
            else:
                params['external_id'] = self.external_id
        if self.footpool_cl_qualified:
            if hasattr(self.footpool_cl_qualified, 'to_alipay_dict'):
                params['footpool_cl_qualified'] = self.footpool_cl_qualified.to_alipay_dict()
            else:
                params['footpool_cl_qualified'] = self.footpool_cl_qualified
        if self.footpool_cl_remain:
            if hasattr(self.footpool_cl_remain, 'to_alipay_dict'):
                params['footpool_cl_remain'] = self.footpool_cl_remain.to_alipay_dict()
            else:
                params['footpool_cl_remain'] = self.footpool_cl_remain
        if self.footpool_cl_remain_standard:
            if hasattr(self.footpool_cl_remain_standard, 'to_alipay_dict'):
                params['footpool_cl_remain_standard'] = self.footpool_cl_remain_standard.to_alipay_dict()
            else:
                params['footpool_cl_remain_standard'] = self.footpool_cl_remain_standard
        if self.limit_num:
            if hasattr(self.limit_num, 'to_alipay_dict'):
                params['limit_num'] = self.limit_num.to_alipay_dict()
            else:
                params['limit_num'] = self.limit_num
        if self.mainpool_cl_qualified:
            if hasattr(self.mainpool_cl_qualified, 'to_alipay_dict'):
                params['mainpool_cl_qualified'] = self.mainpool_cl_qualified.to_alipay_dict()
            else:
                params['mainpool_cl_qualified'] = self.mainpool_cl_qualified
        if self.mainpool_cl_remain:
            if hasattr(self.mainpool_cl_remain, 'to_alipay_dict'):
                params['mainpool_cl_remain'] = self.mainpool_cl_remain.to_alipay_dict()
            else:
                params['mainpool_cl_remain'] = self.mainpool_cl_remain
        if self.mainpool_cl_remain_standard:
            if hasattr(self.mainpool_cl_remain_standard, 'to_alipay_dict'):
                params['mainpool_cl_remain_standard'] = self.mainpool_cl_remain_standard.to_alipay_dict()
            else:
                params['mainpool_cl_remain_standard'] = self.mainpool_cl_remain_standard
        if self.pool_volume:
            if hasattr(self.pool_volume, 'to_alipay_dict'):
                params['pool_volume'] = self.pool_volume.to_alipay_dict()
            else:
                params['pool_volume'] = self.pool_volume
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.water_change:
            if hasattr(self.water_change, 'to_alipay_dict'):
                params['water_change'] = self.water_change.to_alipay_dict()
            else:
                params['water_change'] = self.water_change
        if self.water_change_percent:
            if hasattr(self.water_change_percent, 'to_alipay_dict'):
                params['water_change_percent'] = self.water_change_percent.to_alipay_dict()
            else:
                params['water_change_percent'] = self.water_change_percent
        if self.water_change_qualified:
            if hasattr(self.water_change_qualified, 'to_alipay_dict'):
                params['water_change_qualified'] = self.water_change_qualified.to_alipay_dict()
            else:
                params['water_change_qualified'] = self.water_change_qualified
        if self.water_change_standard:
            if hasattr(self.water_change_standard, 'to_alipay_dict'):
                params['water_change_standard'] = self.water_change_standard.to_alipay_dict()
            else:
                params['water_change_standard'] = self.water_change_standard
        if self.water_check_time:
            if hasattr(self.water_check_time, 'to_alipay_dict'):
                params['water_check_time'] = self.water_check_time.to_alipay_dict()
            else:
                params['water_check_time'] = self.water_check_time
        if self.water_ph:
            if hasattr(self.water_ph, 'to_alipay_dict'):
                params['water_ph'] = self.water_ph.to_alipay_dict()
            else:
                params['water_ph'] = self.water_ph
        if self.water_ph_qualified:
            if hasattr(self.water_ph_qualified, 'to_alipay_dict'):
                params['water_ph_qualified'] = self.water_ph_qualified.to_alipay_dict()
            else:
                params['water_ph_qualified'] = self.water_ph_qualified
        if self.water_ph_standard:
            if hasattr(self.water_ph_standard, 'to_alipay_dict'):
                params['water_ph_standard'] = self.water_ph_standard.to_alipay_dict()
            else:
                params['water_ph_standard'] = self.water_ph_standard
        if self.water_qualified:
            if hasattr(self.water_qualified, 'to_alipay_dict'):
                params['water_qualified'] = self.water_qualified.to_alipay_dict()
            else:
                params['water_qualified'] = self.water_qualified
        if self.water_temperature:
            if hasattr(self.water_temperature, 'to_alipay_dict'):
                params['water_temperature'] = self.water_temperature.to_alipay_dict()
            else:
                params['water_temperature'] = self.water_temperature
        if self.water_temperature_qualified:
            if hasattr(self.water_temperature_qualified, 'to_alipay_dict'):
                params['water_temperature_qualified'] = self.water_temperature_qualified.to_alipay_dict()
            else:
                params['water_temperature_qualified'] = self.water_temperature_qualified
        if self.water_temperature_standard:
            if hasattr(self.water_temperature_standard, 'to_alipay_dict'):
                params['water_temperature_standard'] = self.water_temperature_standard.to_alipay_dict()
            else:
                params['water_temperature_standard'] = self.water_temperature_standard
        if self.water_update_time:
            if hasattr(self.water_update_time, 'to_alipay_dict'):
                params['water_update_time'] = self.water_update_time.to_alipay_dict()
            else:
                params['water_update_time'] = self.water_update_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiServindustryNatatoriumWaterqualityUploadModel()
        if 'commodity_id' in d:
            o.commodity_id = d['commodity_id']
        if 'current_num' in d:
            o.current_num = d['current_num']
        if 'currentnum_update_time' in d:
            o.currentnum_update_time = d['currentnum_update_time']
        if 'external_id' in d:
            o.external_id = d['external_id']
        if 'footpool_cl_qualified' in d:
            o.footpool_cl_qualified = d['footpool_cl_qualified']
        if 'footpool_cl_remain' in d:
            o.footpool_cl_remain = d['footpool_cl_remain']
        if 'footpool_cl_remain_standard' in d:
            o.footpool_cl_remain_standard = d['footpool_cl_remain_standard']
        if 'limit_num' in d:
            o.limit_num = d['limit_num']
        if 'mainpool_cl_qualified' in d:
            o.mainpool_cl_qualified = d['mainpool_cl_qualified']
        if 'mainpool_cl_remain' in d:
            o.mainpool_cl_remain = d['mainpool_cl_remain']
        if 'mainpool_cl_remain_standard' in d:
            o.mainpool_cl_remain_standard = d['mainpool_cl_remain_standard']
        if 'pool_volume' in d:
            o.pool_volume = d['pool_volume']
        if 'remark' in d:
            o.remark = d['remark']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'water_change' in d:
            o.water_change = d['water_change']
        if 'water_change_percent' in d:
            o.water_change_percent = d['water_change_percent']
        if 'water_change_qualified' in d:
            o.water_change_qualified = d['water_change_qualified']
        if 'water_change_standard' in d:
            o.water_change_standard = d['water_change_standard']
        if 'water_check_time' in d:
            o.water_check_time = d['water_check_time']
        if 'water_ph' in d:
            o.water_ph = d['water_ph']
        if 'water_ph_qualified' in d:
            o.water_ph_qualified = d['water_ph_qualified']
        if 'water_ph_standard' in d:
            o.water_ph_standard = d['water_ph_standard']
        if 'water_qualified' in d:
            o.water_qualified = d['water_qualified']
        if 'water_temperature' in d:
            o.water_temperature = d['water_temperature']
        if 'water_temperature_qualified' in d:
            o.water_temperature_qualified = d['water_temperature_qualified']
        if 'water_temperature_standard' in d:
            o.water_temperature_standard = d['water_temperature_standard']
        if 'water_update_time' in d:
            o.water_update_time = d['water_update_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InputInvoiceBillLinkOrderDTO import InputInvoiceBillLinkOrderDTO
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.ApInvoiceLineOrderRequest import ApInvoiceLineOrderRequest
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi


class RelateInputInvoiceOrderDTO(object):

    def __init__(self):
        self._attachment_name = None
        self._attachment_oss_key = None
        self._buyer_address = None
        self._buyer_bank_account = None
        self._buyer_bank_name = None
        self._buyer_inst_id = None
        self._buyer_invoice_title = None
        self._buyer_tax_no = None
        self._buyer_telephone = None
        self._input_invoice_bill_link_order_list = None
        self._inst_id = None
        self._invoice_amt = None
        self._invoice_code = None
        self._invoice_date = None
        self._invoice_line_orders = None
        self._invoice_material = None
        self._invoice_no = None
        self._invoice_note = None
        self._invoice_receive_date = None
        self._invoice_source = None
        self._invoice_type = None
        self._ip_role_id = None
        self._memo = None
        self._operator = None
        self._seller_address = None
        self._seller_bank_account = None
        self._seller_bank_name = None
        self._seller_company_name = None
        self._seller_ip_role_id = None
        self._seller_mid = None
        self._seller_tax_no = None
        self._seller_telephone = None
        self._tax_amt = None
        self._tax_rate = None

    @property
    def attachment_name(self):
        return self._attachment_name

    @attachment_name.setter
    def attachment_name(self, value):
        self._attachment_name = value
    @property
    def attachment_oss_key(self):
        return self._attachment_oss_key

    @attachment_oss_key.setter
    def attachment_oss_key(self, value):
        self._attachment_oss_key = value
    @property
    def buyer_address(self):
        return self._buyer_address

    @buyer_address.setter
    def buyer_address(self, value):
        self._buyer_address = value
    @property
    def buyer_bank_account(self):
        return self._buyer_bank_account

    @buyer_bank_account.setter
    def buyer_bank_account(self, value):
        self._buyer_bank_account = value
    @property
    def buyer_bank_name(self):
        return self._buyer_bank_name

    @buyer_bank_name.setter
    def buyer_bank_name(self, value):
        self._buyer_bank_name = value
    @property
    def buyer_inst_id(self):
        return self._buyer_inst_id

    @buyer_inst_id.setter
    def buyer_inst_id(self, value):
        self._buyer_inst_id = value
    @property
    def buyer_invoice_title(self):
        return self._buyer_invoice_title

    @buyer_invoice_title.setter
    def buyer_invoice_title(self, value):
        self._buyer_invoice_title = value
    @property
    def buyer_tax_no(self):
        return self._buyer_tax_no

    @buyer_tax_no.setter
    def buyer_tax_no(self, value):
        self._buyer_tax_no = value
    @property
    def buyer_telephone(self):
        return self._buyer_telephone

    @buyer_telephone.setter
    def buyer_telephone(self, value):
        self._buyer_telephone = value
    @property
    def input_invoice_bill_link_order_list(self):
        return self._input_invoice_bill_link_order_list

    @input_invoice_bill_link_order_list.setter
    def input_invoice_bill_link_order_list(self, value):
        if isinstance(value, list):
            self._input_invoice_bill_link_order_list = list()
            for i in value:
                if isinstance(i, InputInvoiceBillLinkOrderDTO):
                    self._input_invoice_bill_link_order_list.append(i)
                else:
                    self._input_invoice_bill_link_order_list.append(InputInvoiceBillLinkOrderDTO.from_alipay_dict(i))
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def invoice_amt(self):
        return self._invoice_amt

    @invoice_amt.setter
    def invoice_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._invoice_amt = value
        else:
            self._invoice_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def invoice_code(self):
        return self._invoice_code

    @invoice_code.setter
    def invoice_code(self, value):
        self._invoice_code = value
    @property
    def invoice_date(self):
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, value):
        self._invoice_date = value
    @property
    def invoice_line_orders(self):
        return self._invoice_line_orders

    @invoice_line_orders.setter
    def invoice_line_orders(self, value):
        if isinstance(value, list):
            self._invoice_line_orders = list()
            for i in value:
                if isinstance(i, ApInvoiceLineOrderRequest):
                    self._invoice_line_orders.append(i)
                else:
                    self._invoice_line_orders.append(ApInvoiceLineOrderRequest.from_alipay_dict(i))
    @property
    def invoice_material(self):
        return self._invoice_material

    @invoice_material.setter
    def invoice_material(self, value):
        self._invoice_material = value
    @property
    def invoice_no(self):
        return self._invoice_no

    @invoice_no.setter
    def invoice_no(self, value):
        self._invoice_no = value
    @property
    def invoice_note(self):
        return self._invoice_note

    @invoice_note.setter
    def invoice_note(self, value):
        self._invoice_note = value
    @property
    def invoice_receive_date(self):
        return self._invoice_receive_date

    @invoice_receive_date.setter
    def invoice_receive_date(self, value):
        self._invoice_receive_date = value
    @property
    def invoice_source(self):
        return self._invoice_source

    @invoice_source.setter
    def invoice_source(self, value):
        self._invoice_source = value
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def seller_address(self):
        return self._seller_address

    @seller_address.setter
    def seller_address(self, value):
        self._seller_address = value
    @property
    def seller_bank_account(self):
        return self._seller_bank_account

    @seller_bank_account.setter
    def seller_bank_account(self, value):
        self._seller_bank_account = value
    @property
    def seller_bank_name(self):
        return self._seller_bank_name

    @seller_bank_name.setter
    def seller_bank_name(self, value):
        self._seller_bank_name = value
    @property
    def seller_company_name(self):
        return self._seller_company_name

    @seller_company_name.setter
    def seller_company_name(self, value):
        self._seller_company_name = value
    @property
    def seller_ip_role_id(self):
        return self._seller_ip_role_id

    @seller_ip_role_id.setter
    def seller_ip_role_id(self, value):
        self._seller_ip_role_id = value
    @property
    def seller_mid(self):
        return self._seller_mid

    @seller_mid.setter
    def seller_mid(self, value):
        self._seller_mid = value
    @property
    def seller_tax_no(self):
        return self._seller_tax_no

    @seller_tax_no.setter
    def seller_tax_no(self, value):
        self._seller_tax_no = value
    @property
    def seller_telephone(self):
        return self._seller_telephone

    @seller_telephone.setter
    def seller_telephone(self, value):
        self._seller_telephone = value
    @property
    def tax_amt(self):
        return self._tax_amt

    @tax_amt.setter
    def tax_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._tax_amt = value
        else:
            self._tax_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def tax_rate(self):
        return self._tax_rate

    @tax_rate.setter
    def tax_rate(self, value):
        self._tax_rate = value


    def to_alipay_dict(self):
        params = dict()
        if self.attachment_name:
            if hasattr(self.attachment_name, 'to_alipay_dict'):
                params['attachment_name'] = self.attachment_name.to_alipay_dict()
            else:
                params['attachment_name'] = self.attachment_name
        if self.attachment_oss_key:
            if hasattr(self.attachment_oss_key, 'to_alipay_dict'):
                params['attachment_oss_key'] = self.attachment_oss_key.to_alipay_dict()
            else:
                params['attachment_oss_key'] = self.attachment_oss_key
        if self.buyer_address:
            if hasattr(self.buyer_address, 'to_alipay_dict'):
                params['buyer_address'] = self.buyer_address.to_alipay_dict()
            else:
                params['buyer_address'] = self.buyer_address
        if self.buyer_bank_account:
            if hasattr(self.buyer_bank_account, 'to_alipay_dict'):
                params['buyer_bank_account'] = self.buyer_bank_account.to_alipay_dict()
            else:
                params['buyer_bank_account'] = self.buyer_bank_account
        if self.buyer_bank_name:
            if hasattr(self.buyer_bank_name, 'to_alipay_dict'):
                params['buyer_bank_name'] = self.buyer_bank_name.to_alipay_dict()
            else:
                params['buyer_bank_name'] = self.buyer_bank_name
        if self.buyer_inst_id:
            if hasattr(self.buyer_inst_id, 'to_alipay_dict'):
                params['buyer_inst_id'] = self.buyer_inst_id.to_alipay_dict()
            else:
                params['buyer_inst_id'] = self.buyer_inst_id
        if self.buyer_invoice_title:
            if hasattr(self.buyer_invoice_title, 'to_alipay_dict'):
                params['buyer_invoice_title'] = self.buyer_invoice_title.to_alipay_dict()
            else:
                params['buyer_invoice_title'] = self.buyer_invoice_title
        if self.buyer_tax_no:
            if hasattr(self.buyer_tax_no, 'to_alipay_dict'):
                params['buyer_tax_no'] = self.buyer_tax_no.to_alipay_dict()
            else:
                params['buyer_tax_no'] = self.buyer_tax_no
        if self.buyer_telephone:
            if hasattr(self.buyer_telephone, 'to_alipay_dict'):
                params['buyer_telephone'] = self.buyer_telephone.to_alipay_dict()
            else:
                params['buyer_telephone'] = self.buyer_telephone
        if self.input_invoice_bill_link_order_list:
            if isinstance(self.input_invoice_bill_link_order_list, list):
                for i in range(0, len(self.input_invoice_bill_link_order_list)):
                    element = self.input_invoice_bill_link_order_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.input_invoice_bill_link_order_list[i] = element.to_alipay_dict()
            if hasattr(self.input_invoice_bill_link_order_list, 'to_alipay_dict'):
                params['input_invoice_bill_link_order_list'] = self.input_invoice_bill_link_order_list.to_alipay_dict()
            else:
                params['input_invoice_bill_link_order_list'] = self.input_invoice_bill_link_order_list
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.invoice_amt:
            if hasattr(self.invoice_amt, 'to_alipay_dict'):
                params['invoice_amt'] = self.invoice_amt.to_alipay_dict()
            else:
                params['invoice_amt'] = self.invoice_amt
        if self.invoice_code:
            if hasattr(self.invoice_code, 'to_alipay_dict'):
                params['invoice_code'] = self.invoice_code.to_alipay_dict()
            else:
                params['invoice_code'] = self.invoice_code
        if self.invoice_date:
            if hasattr(self.invoice_date, 'to_alipay_dict'):
                params['invoice_date'] = self.invoice_date.to_alipay_dict()
            else:
                params['invoice_date'] = self.invoice_date
        if self.invoice_line_orders:
            if isinstance(self.invoice_line_orders, list):
                for i in range(0, len(self.invoice_line_orders)):
                    element = self.invoice_line_orders[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.invoice_line_orders[i] = element.to_alipay_dict()
            if hasattr(self.invoice_line_orders, 'to_alipay_dict'):
                params['invoice_line_orders'] = self.invoice_line_orders.to_alipay_dict()
            else:
                params['invoice_line_orders'] = self.invoice_line_orders
        if self.invoice_material:
            if hasattr(self.invoice_material, 'to_alipay_dict'):
                params['invoice_material'] = self.invoice_material.to_alipay_dict()
            else:
                params['invoice_material'] = self.invoice_material
        if self.invoice_no:
            if hasattr(self.invoice_no, 'to_alipay_dict'):
                params['invoice_no'] = self.invoice_no.to_alipay_dict()
            else:
                params['invoice_no'] = self.invoice_no
        if self.invoice_note:
            if hasattr(self.invoice_note, 'to_alipay_dict'):
                params['invoice_note'] = self.invoice_note.to_alipay_dict()
            else:
                params['invoice_note'] = self.invoice_note
        if self.invoice_receive_date:
            if hasattr(self.invoice_receive_date, 'to_alipay_dict'):
                params['invoice_receive_date'] = self.invoice_receive_date.to_alipay_dict()
            else:
                params['invoice_receive_date'] = self.invoice_receive_date
        if self.invoice_source:
            if hasattr(self.invoice_source, 'to_alipay_dict'):
                params['invoice_source'] = self.invoice_source.to_alipay_dict()
            else:
                params['invoice_source'] = self.invoice_source
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.seller_address:
            if hasattr(self.seller_address, 'to_alipay_dict'):
                params['seller_address'] = self.seller_address.to_alipay_dict()
            else:
                params['seller_address'] = self.seller_address
        if self.seller_bank_account:
            if hasattr(self.seller_bank_account, 'to_alipay_dict'):
                params['seller_bank_account'] = self.seller_bank_account.to_alipay_dict()
            else:
                params['seller_bank_account'] = self.seller_bank_account
        if self.seller_bank_name:
            if hasattr(self.seller_bank_name, 'to_alipay_dict'):
                params['seller_bank_name'] = self.seller_bank_name.to_alipay_dict()
            else:
                params['seller_bank_name'] = self.seller_bank_name
        if self.seller_company_name:
            if hasattr(self.seller_company_name, 'to_alipay_dict'):
                params['seller_company_name'] = self.seller_company_name.to_alipay_dict()
            else:
                params['seller_company_name'] = self.seller_company_name
        if self.seller_ip_role_id:
            if hasattr(self.seller_ip_role_id, 'to_alipay_dict'):
                params['seller_ip_role_id'] = self.seller_ip_role_id.to_alipay_dict()
            else:
                params['seller_ip_role_id'] = self.seller_ip_role_id
        if self.seller_mid:
            if hasattr(self.seller_mid, 'to_alipay_dict'):
                params['seller_mid'] = self.seller_mid.to_alipay_dict()
            else:
                params['seller_mid'] = self.seller_mid
        if self.seller_tax_no:
            if hasattr(self.seller_tax_no, 'to_alipay_dict'):
                params['seller_tax_no'] = self.seller_tax_no.to_alipay_dict()
            else:
                params['seller_tax_no'] = self.seller_tax_no
        if self.seller_telephone:
            if hasattr(self.seller_telephone, 'to_alipay_dict'):
                params['seller_telephone'] = self.seller_telephone.to_alipay_dict()
            else:
                params['seller_telephone'] = self.seller_telephone
        if self.tax_amt:
            if hasattr(self.tax_amt, 'to_alipay_dict'):
                params['tax_amt'] = self.tax_amt.to_alipay_dict()
            else:
                params['tax_amt'] = self.tax_amt
        if self.tax_rate:
            if hasattr(self.tax_rate, 'to_alipay_dict'):
                params['tax_rate'] = self.tax_rate.to_alipay_dict()
            else:
                params['tax_rate'] = self.tax_rate
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RelateInputInvoiceOrderDTO()
        if 'attachment_name' in d:
            o.attachment_name = d['attachment_name']
        if 'attachment_oss_key' in d:
            o.attachment_oss_key = d['attachment_oss_key']
        if 'buyer_address' in d:
            o.buyer_address = d['buyer_address']
        if 'buyer_bank_account' in d:
            o.buyer_bank_account = d['buyer_bank_account']
        if 'buyer_bank_name' in d:
            o.buyer_bank_name = d['buyer_bank_name']
        if 'buyer_inst_id' in d:
            o.buyer_inst_id = d['buyer_inst_id']
        if 'buyer_invoice_title' in d:
            o.buyer_invoice_title = d['buyer_invoice_title']
        if 'buyer_tax_no' in d:
            o.buyer_tax_no = d['buyer_tax_no']
        if 'buyer_telephone' in d:
            o.buyer_telephone = d['buyer_telephone']
        if 'input_invoice_bill_link_order_list' in d:
            o.input_invoice_bill_link_order_list = d['input_invoice_bill_link_order_list']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'invoice_amt' in d:
            o.invoice_amt = d['invoice_amt']
        if 'invoice_code' in d:
            o.invoice_code = d['invoice_code']
        if 'invoice_date' in d:
            o.invoice_date = d['invoice_date']
        if 'invoice_line_orders' in d:
            o.invoice_line_orders = d['invoice_line_orders']
        if 'invoice_material' in d:
            o.invoice_material = d['invoice_material']
        if 'invoice_no' in d:
            o.invoice_no = d['invoice_no']
        if 'invoice_note' in d:
            o.invoice_note = d['invoice_note']
        if 'invoice_receive_date' in d:
            o.invoice_receive_date = d['invoice_receive_date']
        if 'invoice_source' in d:
            o.invoice_source = d['invoice_source']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'memo' in d:
            o.memo = d['memo']
        if 'operator' in d:
            o.operator = d['operator']
        if 'seller_address' in d:
            o.seller_address = d['seller_address']
        if 'seller_bank_account' in d:
            o.seller_bank_account = d['seller_bank_account']
        if 'seller_bank_name' in d:
            o.seller_bank_name = d['seller_bank_name']
        if 'seller_company_name' in d:
            o.seller_company_name = d['seller_company_name']
        if 'seller_ip_role_id' in d:
            o.seller_ip_role_id = d['seller_ip_role_id']
        if 'seller_mid' in d:
            o.seller_mid = d['seller_mid']
        if 'seller_tax_no' in d:
            o.seller_tax_no = d['seller_tax_no']
        if 'seller_telephone' in d:
            o.seller_telephone = d['seller_telephone']
        if 'tax_amt' in d:
            o.tax_amt = d['tax_amt']
        if 'tax_rate' in d:
            o.tax_rate = d['tax_rate']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RegionState(object):

    def __init__(self):
        self._floor = None
        self._left_max = None
        self._left_min = None
        self._left_push = None

    @property
    def floor(self):
        return self._floor

    @floor.setter
    def floor(self, value):
        self._floor = value
    @property
    def left_max(self):
        return self._left_max

    @left_max.setter
    def left_max(self, value):
        self._left_max = value
    @property
    def left_min(self):
        return self._left_min

    @left_min.setter
    def left_min(self, value):
        self._left_min = value
    @property
    def left_push(self):
        return self._left_push

    @left_push.setter
    def left_push(self, value):
        self._left_push = value


    def to_alipay_dict(self):
        params = dict()
        if self.floor:
            if hasattr(self.floor, 'to_alipay_dict'):
                params['floor'] = self.floor.to_alipay_dict()
            else:
                params['floor'] = self.floor
        if self.left_max:
            if hasattr(self.left_max, 'to_alipay_dict'):
                params['left_max'] = self.left_max.to_alipay_dict()
            else:
                params['left_max'] = self.left_max
        if self.left_min:
            if hasattr(self.left_min, 'to_alipay_dict'):
                params['left_min'] = self.left_min.to_alipay_dict()
            else:
                params['left_min'] = self.left_min
        if self.left_push:
            if hasattr(self.left_push, 'to_alipay_dict'):
                params['left_push'] = self.left_push.to_alipay_dict()
            else:
                params['left_push'] = self.left_push
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RegionState()
        if 'floor' in d:
            o.floor = d['floor']
        if 'left_max' in d:
            o.left_max = d['left_max']
        if 'left_min' in d:
            o.left_min = d['left_min']
        if 'left_push' in d:
            o.left_push = d['left_push']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BusinessPropertyDTO import BusinessPropertyDTO


class AlipayDataDataservicePropertyBusinesspropertyBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataDataservicePropertyBusinesspropertyBatchqueryResponse, self).__init__()
        self._business_propertys = None

    @property
    def business_propertys(self):
        return self._business_propertys

    @business_propertys.setter
    def business_propertys(self, value):
        if isinstance(value, list):
            self._business_propertys = list()
            for i in value:
                if isinstance(i, BusinessPropertyDTO):
                    self._business_propertys.append(i)
                else:
                    self._business_propertys.append(BusinessPropertyDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayDataDataservicePropertyBusinesspropertyBatchqueryResponse, self).parse_response_content(response_content)
        if 'business_propertys' in response:
            self.business_propertys = response['business_propertys']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VoucherFileInfo(object):

    def __init__(self):
        self._file_download_url = None
        self._file_name = None
        self._file_type = None

    @property
    def file_download_url(self):
        return self._file_download_url

    @file_download_url.setter
    def file_download_url(self, value):
        self._file_download_url = value
    @property
    def file_name(self):
        return self._file_name

    @file_name.setter
    def file_name(self, value):
        self._file_name = value
    @property
    def file_type(self):
        return self._file_type

    @file_type.setter
    def file_type(self, value):
        self._file_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.file_download_url:
            if hasattr(self.file_download_url, 'to_alipay_dict'):
                params['file_download_url'] = self.file_download_url.to_alipay_dict()
            else:
                params['file_download_url'] = self.file_download_url
        if self.file_name:
            if hasattr(self.file_name, 'to_alipay_dict'):
                params['file_name'] = self.file_name.to_alipay_dict()
            else:
                params['file_name'] = self.file_name
        if self.file_type:
            if hasattr(self.file_type, 'to_alipay_dict'):
                params['file_type'] = self.file_type.to_alipay_dict()
            else:
                params['file_type'] = self.file_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherFileInfo()
        if 'file_download_url' in d:
            o.file_download_url = d['file_download_url']
        if 'file_name' in d:
            o.file_name = d['file_name']
        if 'file_type' in d:
            o.file_type = d['file_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PortraitDistribution(object):

    def __init__(self):
        self._key = None
        self._number = None
        self._ratio = None

    @property
    def key(self):
        return self._key

    @key.setter
    def key(self, value):
        self._key = value
    @property
    def number(self):
        return self._number

    @number.setter
    def number(self, value):
        self._number = value
    @property
    def ratio(self):
        return self._ratio

    @ratio.setter
    def ratio(self, value):
        self._ratio = value


    def to_alipay_dict(self):
        params = dict()
        if self.key:
            if hasattr(self.key, 'to_alipay_dict'):
                params['key'] = self.key.to_alipay_dict()
            else:
                params['key'] = self.key
        if self.number:
            if hasattr(self.number, 'to_alipay_dict'):
                params['number'] = self.number.to_alipay_dict()
            else:
                params['number'] = self.number
        if self.ratio:
            if hasattr(self.ratio, 'to_alipay_dict'):
                params['ratio'] = self.ratio.to_alipay_dict()
            else:
                params['ratio'] = self.ratio
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PortraitDistribution()
        if 'key' in d:
            o.key = d['key']
        if 'number' in d:
            o.number = d['number']
        if 'ratio' in d:
            o.ratio = d['ratio']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.KbdishCookInfo import KbdishCookInfo


class KoubeiCateringDishCookSyncResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiCateringDishCookSyncResponse, self).__init__()
        self._kb_dish_cook = None

    @property
    def kb_dish_cook(self):
        return self._kb_dish_cook

    @kb_dish_cook.setter
    def kb_dish_cook(self, value):
        if isinstance(value, KbdishCookInfo):
            self._kb_dish_cook = value
        else:
            self._kb_dish_cook = KbdishCookInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(KoubeiCateringDishCookSyncResponse, self).parse_response_content(response_content)
        if 'kb_dish_cook' in response:
            self.kb_dish_cook = response['kb_dish_cook']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditEpCertificationInitializeModel(object):

    def __init__(self):
        self._certify_category = None
        self._certify_return_url = None
        self._ep_cert_no = None
        self._ep_name = None
        self._org_biz_no = None
        self._product_code = None
        self._user_cert_no = None
        self._user_id = None
        self._user_name = None

    @property
    def certify_category(self):
        return self._certify_category

    @certify_category.setter
    def certify_category(self, value):
        self._certify_category = value
    @property
    def certify_return_url(self):
        return self._certify_return_url

    @certify_return_url.setter
    def certify_return_url(self, value):
        self._certify_return_url = value
    @property
    def ep_cert_no(self):
        return self._ep_cert_no

    @ep_cert_no.setter
    def ep_cert_no(self, value):
        self._ep_cert_no = value
    @property
    def ep_name(self):
        return self._ep_name

    @ep_name.setter
    def ep_name(self, value):
        self._ep_name = value
    @property
    def org_biz_no(self):
        return self._org_biz_no

    @org_biz_no.setter
    def org_biz_no(self, value):
        self._org_biz_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def user_cert_no(self):
        return self._user_cert_no

    @user_cert_no.setter
    def user_cert_no(self, value):
        self._user_cert_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.certify_category:
            if hasattr(self.certify_category, 'to_alipay_dict'):
                params['certify_category'] = self.certify_category.to_alipay_dict()
            else:
                params['certify_category'] = self.certify_category
        if self.certify_return_url:
            if hasattr(self.certify_return_url, 'to_alipay_dict'):
                params['certify_return_url'] = self.certify_return_url.to_alipay_dict()
            else:
                params['certify_return_url'] = self.certify_return_url
        if self.ep_cert_no:
            if hasattr(self.ep_cert_no, 'to_alipay_dict'):
                params['ep_cert_no'] = self.ep_cert_no.to_alipay_dict()
            else:
                params['ep_cert_no'] = self.ep_cert_no
        if self.ep_name:
            if hasattr(self.ep_name, 'to_alipay_dict'):
                params['ep_name'] = self.ep_name.to_alipay_dict()
            else:
                params['ep_name'] = self.ep_name
        if self.org_biz_no:
            if hasattr(self.org_biz_no, 'to_alipay_dict'):
                params['org_biz_no'] = self.org_biz_no.to_alipay_dict()
            else:
                params['org_biz_no'] = self.org_biz_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.user_cert_no:
            if hasattr(self.user_cert_no, 'to_alipay_dict'):
                params['user_cert_no'] = self.user_cert_no.to_alipay_dict()
            else:
                params['user_cert_no'] = self.user_cert_no
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.user_name:
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditEpCertificationInitializeModel()
        if 'certify_category' in d:
            o.certify_category = d['certify_category']
        if 'certify_return_url' in d:
            o.certify_return_url = d['certify_return_url']
        if 'ep_cert_no' in d:
            o.ep_cert_no = d['ep_cert_no']
        if 'ep_name' in d:
            o.ep_name = d['ep_name']
        if 'org_biz_no' in d:
            o.org_biz_no = d['org_biz_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'user_cert_no' in d:
            o.user_cert_no = d['user_cert_no']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'user_name' in d:
            o.user_name = d['user_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMerchantComplainGovernmentFinishModel(object):

    def __init__(self):
        self._complain_event_id = None
        self._finish_memo = None
        self._government_agency = None

    @property
    def complain_event_id(self):
        return self._complain_event_id

    @complain_event_id.setter
    def complain_event_id(self, value):
        self._complain_event_id = value
    @property
    def finish_memo(self):
        return self._finish_memo

    @finish_memo.setter
    def finish_memo(self, value):
        self._finish_memo = value
    @property
    def government_agency(self):
        return self._government_agency

    @government_agency.setter
    def government_agency(self, value):
        self._government_agency = value


    def to_alipay_dict(self):
        params = dict()
        if self.complain_event_id:
            if hasattr(self.complain_event_id, 'to_alipay_dict'):
                params['complain_event_id'] = self.complain_event_id.to_alipay_dict()
            else:
                params['complain_event_id'] = self.complain_event_id
        if self.finish_memo:
            if hasattr(self.finish_memo, 'to_alipay_dict'):
                params['finish_memo'] = self.finish_memo.to_alipay_dict()
            else:
                params['finish_memo'] = self.finish_memo
        if self.government_agency:
            if hasattr(self.government_agency, 'to_alipay_dict'):
                params['government_agency'] = self.government_agency.to_alipay_dict()
            else:
                params['government_agency'] = self.government_agency
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantComplainGovernmentFinishModel()
        if 'complain_event_id' in d:
            o.complain_event_id = d['complain_event_id']
        if 'finish_memo' in d:
            o.finish_memo = d['finish_memo']
        if 'government_agency' in d:
            o.government_agency = d['government_agency']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ActivityGoods(object):

    def __init__(self):
        self._barcode = None
        self._benefit_id = None
        self._benefit_name = None
        self._stock = None

    @property
    def barcode(self):
        return self._barcode

    @barcode.setter
    def barcode(self, value):
        self._barcode = value
    @property
    def benefit_id(self):
        return self._benefit_id

    @benefit_id.setter
    def benefit_id(self, value):
        self._benefit_id = value
    @property
    def benefit_name(self):
        return self._benefit_name

    @benefit_name.setter
    def benefit_name(self, value):
        self._benefit_name = value
    @property
    def stock(self):
        return self._stock

    @stock.setter
    def stock(self, value):
        self._stock = value


    def to_alipay_dict(self):
        params = dict()
        if self.barcode:
            if hasattr(self.barcode, 'to_alipay_dict'):
                params['barcode'] = self.barcode.to_alipay_dict()
            else:
                params['barcode'] = self.barcode
        if self.benefit_id:
            if hasattr(self.benefit_id, 'to_alipay_dict'):
                params['benefit_id'] = self.benefit_id.to_alipay_dict()
            else:
                params['benefit_id'] = self.benefit_id
        if self.benefit_name:
            if hasattr(self.benefit_name, 'to_alipay_dict'):
                params['benefit_name'] = self.benefit_name.to_alipay_dict()
            else:
                params['benefit_name'] = self.benefit_name
        if self.stock:
            if hasattr(self.stock, 'to_alipay_dict'):
                params['stock'] = self.stock.to_alipay_dict()
            else:
                params['stock'] = self.stock
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ActivityGoods()
        if 'barcode' in d:
            o.barcode = d['barcode']
        if 'benefit_id' in d:
            o.benefit_id = d['benefit_id']
        if 'benefit_name' in d:
            o.benefit_name = d['benefit_name']
        if 'stock' in d:
            o.stock = d['stock']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarParkingPayQueryModel(object):

    def __init__(self):
        self._out_order_no = None
        self._plate_color = None
        self._plate_no = None

    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def plate_color(self):
        return self._plate_color

    @plate_color.setter
    def plate_color(self, value):
        self._plate_color = value
    @property
    def plate_no(self):
        return self._plate_no

    @plate_no.setter
    def plate_no(self, value):
        self._plate_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.plate_color:
            if hasattr(self.plate_color, 'to_alipay_dict'):
                params['plate_color'] = self.plate_color.to_alipay_dict()
            else:
                params['plate_color'] = self.plate_color
        if self.plate_no:
            if hasattr(self.plate_no, 'to_alipay_dict'):
                params['plate_no'] = self.plate_no.to_alipay_dict()
            else:
                params['plate_no'] = self.plate_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarParkingPayQueryModel()
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'plate_color' in d:
            o.plate_color = d['plate_color']
        if 'plate_no' in d:
            o.plate_no = d['plate_no']
        return o


